@@ -1,4 +1,4 @@
-      program pdndrv1 
+      program pdndrv1
 c
 c     Message Passing Layer: MPI
 c
@@ -10,7 +10,7 @@ c
 c\Example-1
 c     ... Suppose we want to solve A*x = lambda*x in regular mode,
 c         where A is obtained from the standard central difference
-c         discretization of the convection-diffusion operator 
+c         discretization of the convection-diffusion operator
 c                 (Laplacian u) + rho*(du / dx)
 c         on the unit square, with zero Dirichlet boundary condition.
 c
@@ -28,7 +28,7 @@ c     dlapy2   LAPACK routine to compute sqrt(x**2+y**2) carefully.
 c     daxpy    Level 1 BLAS that computes y <- alpha*x+y.
 c     pdnorm2  Parallel version of Level 1 BLAS that computes the norm of a vector.
 c     av       Distributed matrix vector multiplication routine that computes A*x.
-c     tv       Matrix vector multiplication routine that computes T*x, 
+c     tv       Matrix vector multiplication routine that computes T*x,
 c              where T is a tridiagonal matrix.  It is used in routine
 c              av.
 c
@@ -47,7 +47,7 @@ c
 c\Revision history:
 c     Starting Point: Serial Code FILE: ndrv1.F   SID: 2.2
 c
-c\SCCS Information: 
+c\SCCS Information:
 c FILE: ndrv1.F   SID: 1.2   DATE OF SID: 8/14/96   RELEASE: 1
 c
 c\Remarks
@@ -59,11 +59,18 @@ c
       include 'mpif.h'
       include 'debug.h'
       include 'stat.h'
- 
-c     %---------------%
-c     | MPI INTERFACE |
-c     %---------------%
-      integer           comm, myid, nprocs, rc, nloc 
+
+c     %-------------------------------%
+c     | MPI INTERFACE                 |
+c     | ILP64 is not supported by MPI |
+c     | integer*4 must be imposed in  |
+c     | all calls involving MPI.      |
+c     |                               |
+c     | Use ierr for MPI calls.       |
+c     %-------------------------------%
+
+      integer*4         comm, myid, nprocs, rc, ierr
+
 c
 c     %-----------------------------%
 c     | Define maximum dimensions   |
@@ -85,18 +92,21 @@ c
       integer           iparam(11), ipntr(14)
       logical           select(maxncv)
       Double precision
-     &                  ax(maxnloc), d(maxncv,3), resid(maxnloc), 
-     &                  v(ldv,maxncv), workd(3*maxnloc), 
-     &                  workev(3*maxncv), 
+     &                  ax(maxnloc), d(maxncv,3), resid(maxnloc),
+     &                  v(ldv,maxncv), workd(3*maxnloc),
+     &                  workev(3*maxncv),
      &                  workl(3*maxncv*maxncv+6*maxncv)
 c
-c     %---------------%
-c     | Local Scalars |
-c     %---------------%
+c     %------------------------------------%
+c     | Local Scalars                      |
+c     |                                    |
+c     | Use info if ILP64 can be supported |
+c     | (call to BLAS, LAPACK, ARPACK).    |
+c     %------------------------------------%
 c
       character         bmat*1, which*2
       integer           ido, n, nx, nev, ncv, lworkl, info, j,
-     &                  ierr, nconv, maxitr, ishfts, mode
+     &                  nloc, nconv, maxitr, ishfts, mode
       Double precision
      &                  tol, sigmar, sigmai
       logical           first, rvec
@@ -147,7 +157,7 @@ c     %--------------------------------------------------%
 c     | The number NX is the number of interior points   |
 c     | in the discretization of the 2-dimensional       |
 c     | convection-diffusion operator on the unit        |
-c     | square with zero Dirichlet boundary condition.   | 
+c     | square with zero Dirichlet boundary condition.   |
 c     | The number N(=NX*NX) is the dimension of the     |
 c     | matrix.  A standard eigenvalue problem is        |
 c     | solved (BMAT = 'I').  NEV is the number of       |
@@ -158,13 +168,13 @@ c     | the spectrum.  However, The following            |
 c     | conditions must be satisfied:                    |
 c     |                   N <= MAXN                      |
 c     |                 NEV <= MAXNEV                    |
-c     |           NEV + 2 <= NCV <= MAXNCV               | 
-c     %--------------------------------------------------% 
+c     |           NEV + 2 <= NCV <= MAXNCV               |
+c     %--------------------------------------------------%
 c
-      nx    = 10 
-      n     = nx*nx 
+      nx    = 10
+      n     = nx*nx
       nev   = 4
-      ncv   = 20 
+      ncv   = 20
 c
 c     %--------------------------------------%
 c     | Set up distribution of data to nodes |
@@ -187,18 +197,18 @@ c
       which = 'SM'
 c
 c     %-----------------------------------------------------%
-c     | The work array WORKL is used in PDNAUPD as          |  
+c     | The work array WORKL is used in PDNAUPD as          |
 c     | workspace.  Its dimension LWORKL is set as          |
 c     | illustrated below.  The parameter TOL determines    |
 c     | the stopping criterion. If TOL<=0, machine          |
 c     | precision is used.  The variable IDO is used for    |
 c     | reverse communication, and is initially set to 0.   |
 c     | Setting INFO=0 indicates that a random vector is    |
-c     | generated in PDNAUPD to start the Arnoldi iteration.| 
+c     | generated in PDNAUPD to start the Arnoldi iteration.|
 c     %-----------------------------------------------------%
 c
-      lworkl  = 3*ncv**2+6*ncv 
-      tol    = zero 
+      lworkl  = 3*ncv**2+6*ncv
+      tol    = zero
       ido    = 0
       info   = 0
 c
@@ -217,11 +227,11 @@ c
       mode   = 1
 c
       iparam(1) = ishfts
-      iparam(3) = maxitr 
+      iparam(3) = maxitr
       iparam(7) = mode
 c
 c     %-------------------------------------------%
-c     | M A I N   L O O P (Reverse communication) | 
+c     | M A I N   L O O P (Reverse communication) |
 c     %-------------------------------------------%
 c
  10   continue
@@ -233,7 +243,7 @@ c        | either convergence is indicated or maxitr   |
 c        | has been exceeded.                          |
 c        %---------------------------------------------%
 c
-         call pdnaupd(comm, ido, bmat, nloc, which, nev, tol, resid, 
+         call pdnaupd(comm, ido, bmat, nloc, which, nev, tol, resid,
      &        ncv, v, ldv, iparam, ipntr, workd, workl, lworkl, info )
 c
          if (ido .eq. -1 .or. ido .eq. 1) then
@@ -245,10 +255,10 @@ c           | The user should supply his/her own        |
 c           | matrix vector multiplication routine here |
 c           | that takes workd(ipntr(1)) as the input   |
 c           | vector, and return the matrix vector      |
-c           | product to workd(ipntr(2)).               | 
+c           | product to workd(ipntr(2)).               |
 c           %-------------------------------------------%
 c
-            call av ( comm, nloc, nx, mv_buf, 
+            call av ( comm, nloc, nx, mv_buf,
      &                workd(ipntr(1)), workd(ipntr(2)))
 c
 c           %-----------------------------------------%
@@ -257,8 +267,8 @@ c           %-----------------------------------------%
 c
             go to 10
 c
-      end if 
-c 
+      end if
+c
 c     %----------------------------------------%
 c     | Either we have convergence or there is |
 c     | an error.                              |
@@ -278,7 +288,7 @@ c
             print *, ' '
          endif
 c
-      else 
+      else
 c
 c        %-------------------------------------------%
 c        | No fatal errors occurred.                 |
@@ -292,10 +302,10 @@ c        %-------------------------------------------%
 c
          rvec = .true.
 c
-         call pdneupd ( comm, rvec, 'A', select, d, d(1,2), v, ldv, 
-     &        sigmar, sigmai, workev, bmat, nloc, which, nev, tol, 
+         call pdneupd ( comm, rvec, 'A', select, d, d(1,2), v, ldv,
+     &        sigmar, sigmai, workev, bmat, nloc, which, nev, tol,
      &        resid, ncv, v, ldv, iparam, ipntr, workd, workl,
-     &        lworkl, ierr )
+     &        lworkl, info )
 c
 c        %-----------------------------------------------%
 c        | The real part of the eigenvalue is returned   |
@@ -309,7 +319,7 @@ c        | for the invariant subspace corresponding to   |
 c        | the eigenvalues in D is returned in V.        |
 c        %-----------------------------------------------%
 c
-         if ( ierr .ne. 0) then
+         if ( info .ne. 0) then
 c
 c           %------------------------------------%
 c           | Error condition:                   |
@@ -318,12 +328,12 @@ c           %------------------------------------%
 c
          	if ( myid .eq. 0 ) then
              	print *, ' '
-             	print *, ' Error with _neupd, info = ', ierr
+             	print *, ' Error with _neupd, info = ', info
              	print *, ' Check the documentation of _neupd. '
              	print *, ' '
             endif
 c
-         else 
+         else
 c
              first  = .true.
              nconv  = iparam(5)
@@ -350,7 +360,7 @@ c                  %--------------------%
 c
                    call av(comm, nloc, nx, mv_buf, v(1,j), ax)
                    call daxpy(nloc, -d(j,1), v(1,j), 1, ax, 1)
-                   d(j,3) = pdnorm2( comm, nloc, ax, 1)                   
+                   d(j,3) = pdnorm2( comm, nloc, ax, 1)
 c
                 else if (first) then
 c
@@ -358,9 +368,9 @@ c                  %------------------------%
 c                  | Ritz value is complex. |
 c                  | Residual of one Ritz   |
 c                  | value of the conjugate |
-c                  | pair is computed.      | 
+c                  | pair is computed.      |
 c                  %------------------------%
-c        
+c
                    call av(comm, nloc, nx, mv_buf, v(1,j), ax)
                    call daxpy(nloc, -d(j,1), v(1,j), 1, ax, 1)
                    call daxpy(nloc, d(j,2), v(1,j+1), 1, ax, 1)
@@ -395,24 +405,24 @@ c
              print *, ' Maximum number of iterations reached.'
              print *, ' '
          else if ( info .eq. 3) then
-             print *, ' ' 
+             print *, ' '
              print *, ' No shifts could be applied during implicit
      &                  Arnoldi update, try increasing NCV.'
              print *, ' '
-         end if      
+         end if
 c
          print *, ' '
          print *, '_NDRV1 '
          print *, '====== '
-         print *, ' ' 
+         print *, ' '
          print *, ' Size of the matrix is ', n
          print *, ' The number of processors is ', nprocs
          print *, ' The number of Ritz values requested is ', nev
          print *, ' The number of Arnoldi vectors generated',
      &            ' (NCV) is ', ncv
          print *, ' What portion of the spectrum: ', which
-         print *, ' The number of converged Ritz values is ', 
-     &              nconv 
+         print *, ' The number of converged Ritz values is ',
+     &              nconv
          print *, ' The number of Implicit Arnoldi update',
      &            ' iterations taken is ', iparam(3)
          print *, ' The number of OP*x is ', iparam(9)
@@ -435,30 +445,30 @@ c
       call MPI_FINALIZE(rc)
 c
       end
-c 
+c
 c==========================================================================
 c
 c     parallel matrix vector subroutine
 c
-c     The matrix used is the 2 dimensional convection-diffusion 
+c     The matrix used is the 2 dimensional convection-diffusion
 c     operator discretized using central difference.
 c
-c     Computes w <--- OP*v, where OP is the nx*nx by nx*nx block 
+c     Computes w <--- OP*v, where OP is the nx*nx by nx*nx block
 c     tridiagonal matrix
 c
-c                  | T -I          | 
+c                  | T -I          |
 c                  |-I  T -I       |
 c             OP = |   -I  T       |
 c                  |        ...  -I|
 c                  |           -I T|
 c
-c     derived from the standard central difference discretization 
-c     of the 2 dimensional convection-diffusion operator 
-c     (Laplacian u) + rho*(du/dx) on a unit square with zero boundary 
+c     derived from the standard central difference discretization
+c     of the 2 dimensional convection-diffusion operator
+c     (Laplacian u) + rho*(du/dx) on a unit square with zero boundary
 c     condition.
 c
-c     When rho*h/2 <= 1, the discrete convection-diffusion operator 
-c     has real eigenvalues.  When rho*h/2 > 1, it has COMPLEX 
+c     When rho*h/2 <= 1, the discrete convection-diffusion operator
+c     has real eigenvalues.  When rho*h/2 > 1, it has COMPLEX
 c     eigenvalues.
 c
 c     The subroutine TV is called to compute y<---T*x.
@@ -468,7 +478,7 @@ c----------------------------------------------------------------------------
 c
 c     .. MPI Declarations ...
       include           'mpif.h'
-      integer           comm, nprocs, myid, ierr,
+      integer*4         comm, nprocs, myid, ierr,
      &                  status(MPI_STATUS_SIZE)
 c
       integer           nloc, nx, np, j, lo, next, prev
@@ -489,14 +499,14 @@ c
          call tv(nx, v(lo+1), w(lo+1))
          call daxpy(nx, -one, v(lo-nx+1), 1, w(lo+1), 1)
          call daxpy(nx, -one, v(lo+nx+1), 1, w(lo+1), 1)
-  10  continue 
+  10  continue
 c
       lo = (np-1)*nx
       call tv(nx, v(lo+1), w(lo+1))
       call daxpy(nx, -one, v(lo-nx+1), 1, w(lo+1), 1)
 c
       next = myid + 1
-      prev = myid - 1 
+      prev = myid - 1
       if ( myid .lt. nprocs-1 ) then
          call mpi_send( v((np-1)*nx+1), nx, MPI_DOUBLE_PRECISION,
      &                  next, myid+1, comm, ierr )
@@ -504,7 +514,7 @@ c
       if ( myid .gt. 0 ) then
          call mpi_recv( mv_buf, nx, MPI_DOUBLE_PRECISION, prev, myid,
      &                  comm, status, ierr )
-         call daxpy( nx, -one, mv_buf, 1, w(1), 1 )		
+         call daxpy( nx, -one, mv_buf, 1, w(1), 1 )
       endif
 c
       if ( myid .gt. 0 ) then
@@ -514,7 +524,7 @@ c
       if ( myid .lt. nprocs-1 ) then
          call mpi_recv( mv_buf, nx, MPI_DOUBLE_PRECISION, next, myid,
      &                  comm, status, ierr )
-         call daxpy( nx, -one, mv_buf, 1, w(lo+1), 1 )		
+         call daxpy( nx, -one, mv_buf, 1, w(lo+1), 1 )
       endif
 c
       return
@@ -522,32 +532,32 @@ c
 c=========================================================================
       subroutine tv (nx, x, y)
 c
-      integer           nx, j 
+      integer           nx, j
       Double precision
      &                  x(nx), y(nx), h, dd, dl, du
 c
       Double precision
      &                  one, zero, rho
-      parameter         (one = 1.0, zero = 0.0, 
+      parameter         (one = 1.0, zero = 0.0,
      &                   rho = 0.0)
 c
 c     Compute the matrix vector multiplication y<---T*x
-c     where T is a nx by nx tridiagonal matrix with DD on the 
+c     where T is a nx by nx tridiagonal matrix with DD on the
 c     diagonal, DL on the subdiagonal, and DU on the superdiagonal.
 c
-c     When rho*h/2 <= 1, the discrete convection-diffusion operator 
-c     has real eigenvalues.  When rho*h/2 > 1, it has COMPLEX 
+c     When rho*h/2 <= 1, the discrete convection-diffusion operator
+c     has real eigenvalues.  When rho*h/2 > 1, it has COMPLEX
 c     eigenvalues.
 c
       h   = one / dble(nx+1)
       dd  = 4.0*one
       dl  = -one - 0.5*rho*h
       du  = -one + 0.5*rho*h
-c 
+c
       y(1) =  dd*x(1) + du*x(2)
       do 10 j = 2,nx-1
-         y(j) = dl*x(j-1) + dd*x(j) + du*x(j+1) 
- 10   continue 
-      y(nx) =  dl*x(nx-1) + dd*x(nx) 
+         y(j) = dl*x(j-1) + dd*x(j) + du*x(j+1)
+ 10   continue
+      y(nx) =  dl*x(nx-1) + dd*x(nx)
       return
       end
