@@ -57,11 +57,17 @@ c
       include 'debug.h'
       include 'stat.h'
 
-c     %---------------%
-c     | MPI INTERFACE |
-c     %---------------%
+c     %-------------------------------%
+c     | MPI INTERFACE                 |
+c     | ILP64 is not supported by MPI |
+c     | integer*4 must be imposed in  |
+c     | all calls involving MPI.      |
+c     |                               |
+c     | Use ierr for MPI calls.       |
+c     %-------------------------------%
+
+      integer*4         comm, myid, nprocs, rc, ierr
 
-      integer           comm, myid, nprocs, rc, nloc
 c
 c     %-----------------------------%
 c     | Define leading dimensions   |
@@ -87,12 +93,15 @@ c
       logical          select(maxncv)
       integer          iparam(11), ipntr(11)
 c
-c     %---------------%
-c     | Local Scalars |
-c     %---------------%
+c     %------------------------------------%
+c     | Local Scalars                      |
+c     |                                    |
+c     | Use info if ILP64 can be supported |
+c     | (call to BLAS, LAPACK, ARPACK).    |
+c     %------------------------------------%
 c
       character        bmat*1, which*2
-      integer          ido, n, nev, ncv, lworkl, info, ierr, j,
+      integer          ido, n, nev, ncv, lworkl, info, nloc, j,
      &                 nx, nconv, maxitr, mode, ishfts
       logical          rvec
       Double precision
@@ -293,7 +302,7 @@ c
          call pdseupd ( comm, rvec, 'All', select,
      &        d, v, ldv, sigma,
      &        bmat, nloc, which, nev, tol, resid, ncv, v, ldv,
-     &        iparam, ipntr, workd, workl, lworkl, ierr )
+     &        iparam, ipntr, workd, workl, lworkl, info )
 c        %----------------------------------------------%
 c        | Eigenvalues are returned in the first column |
 c        | of the two dimensional array D and the       |
@@ -305,7 +314,7 @@ c        | corresponding to the eigenvalues in D is     |
 c        | returned in V.                               |
 c        %----------------------------------------------%
 c
-         if ( ierr .ne. 0) then
+         if ( info .ne. 0) then
 c
 c            %------------------------------------%
 c            | Error condition:                   |
@@ -315,7 +324,7 @@ c
 c
             if ( myid .eq. 0 ) then
              	print *, ' '
-             	print *, ' Error with _seupd, info = ', ierr
+             	print *, ' Error with _seupd, info = ', info
              	print *, ' Check the documentation of _seupd. '
              	print *, ' '
             endif
@@ -421,7 +430,7 @@ c
 c
 c     .. MPI Declarations ...
       include           'mpif.h'
-      integer           comm, nprocs, myid, ierr,
+      integer*4         comm, nprocs, myid, ierr,
      &                  status(MPI_STATUS_SIZE)
       integer           nloc, nx, np, j, lo, next, prev
       Double precision
