@@ -17,7 +17,7 @@ c\Arguments
 c  COMM    BLACS Communicator for the processor grid.  (INPUT)
 c
 c  RNORM   Real scalar.  (INPUT)
-c          Residual norm corresponding to the current upper Hessenberg 
+c          Residual norm corresponding to the current upper Hessenberg
 c          matrix H.
 c
 c  N       Integer.  (INPUT)
@@ -31,13 +31,13 @@ c          Leading dimension of H exactly as declared in the calling
 c          program.
 c
 c  RITZR,  Real arrays of length N.  (OUTPUT)
-c  RITZI   On output, RITZR(1:N) (resp. RITZI(1:N)) contains the real 
+c  RITZI   On output, RITZR(1:N) (resp. RITZI(1:N)) contains the real
 c          (respectively imaginary) parts of the eigenvalues of H.
 c
 c  BOUNDS  Real array of length N.  (OUTPUT)
 c          On output, BOUNDS contains the Ritz estimates associated with
-c          the eigenvalues RITZR and RITZI.  This is equal to RNORM 
-c          times the last components of the eigenvectors corresponding 
+c          the eigenvalues RITZR and RITZI.  This is equal to RNORM
+c          times the last components of the eigenvectors corresponding
 c          to the eigenvalues in RITZR and RITZI.
 c
 c  Q       Real N by N array.  (WORKSPACE)
@@ -53,7 +53,7 @@ c          the front end.  This is needed to keep the full Schur form
 c          of H and also in the calculation of the eigenvectors of H.
 c
 c  IERR    Integer.  (OUTPUT)
-c          Error exit flag from slaqrb or strevc.
+c          Error exit flag from slahqr or strevc.
 c
 c\EndDoc
 c
@@ -65,7 +65,7 @@ c\Local variables:
 c     xxxxxx  real
 c
 c\Routines called:
-c     slaqrb  ARPACK routine to compute the real Schur form of an
+c     slahqr  ARPACK routine to compute the real Schur form of an
 c             upper Hessenberg matrix and last row of the Schur vectors.
 c     arscnd  ARPACK utility routine for timing.
 c     smout   ARPACK utility routine that prints matrices
@@ -78,15 +78,15 @@ c     sgemv   Level 2 BLAS routine for matrix vector multiplication.
 c     scopy   Level 1 BLAS that copies one vector to another .
 c     snrm2   Level 1 BLAS that computes the norm of a vector.
 c     sscal   Level 1 BLAS that scales a vector.
-c     
+c
 c
 c\Author
 c     Danny Sorensen               Phuong Vu
 c     Richard Lehoucq              Cray Research, Inc. &
 c     Dept. of Computational &     CRPC / Rice University
 c     Applied Mathematics          Houston, Texas
-c     Rice University           
-c     Houston, Texas    
+c     Rice University
+c     Houston, Texas
 c
 c\Parallel Modifications
 c     Kristi Maschhoff
@@ -94,8 +94,8 @@ c
 c\Revision history:
 c     Starting Point: Serial Code FILE: neigh.F   SID: 2.2
 c
-c\SCCS Information: 
-c FILE: neigh.F   SID: 1.2   DATE OF SID: 2/22/96   
+c\SCCS Information:
+c FILE: neigh.F   SID: 1.2   DATE OF SID: 2/22/96
 c
 c\Remarks
 c     None
@@ -104,7 +104,7 @@ c\EndLib
 c
 c-----------------------------------------------------------------------
 c
-      subroutine psneigh ( comm, rnorm, n, h, ldh, ritzr, ritzi, bounds, 
+      subroutine psneigh ( comm, rnorm, n, h, ldh, ritzr, ritzi, bounds,
      &                    q, ldq, workl, ierr)
 c
 c     %--------------------%
@@ -125,39 +125,39 @@ c     | Scalar Arguments |
 c     %------------------%
 c
       integer    ierr, n, ldh, ldq
-      Real     
+      Real
      &           rnorm
 c
 c     %-----------------%
 c     | Array Arguments |
 c     %-----------------%
 c
-      Real     
+      Real
      &           bounds(n), h(ldh,n), q(ldq,n), ritzi(n), ritzr(n),
      &           workl(n*(n+3))
-c 
+c
 c     %------------%
 c     | Parameters |
 c     %------------%
 c
-      Real     
+      Real
      &           one, zero
       parameter (one = 1.0, zero = 0.0)
-c 
+c
 c     %------------------------%
 c     | Local Scalars & Arrays |
 c     %------------------------%
 c
       logical    select(1)
       integer    i, iconj, msglvl
-      Real     
+      Real
      &           temp, vl(1)
 c
 c     %----------------------%
 c     | External Subroutines |
 c     %----------------------%
 c
-      external   scopy, slacpy, slaqrb, strevc, psvout, arscnd
+      external   scopy, slacpy, slahqr, strevc, svout, arscnd
 c
 c     %--------------------%
 c     | External Functions |
@@ -185,23 +185,27 @@ c     %-------------------------------%
 c
       call arscnd (t0)
       msglvl = mneigh
-c 
+c
       if (msglvl .gt. 2) then
-          call psmout (comm, logfil, n, n, h, ldh, ndigit, 
+          call psmout (comm, logfil, n, n, h, ldh, ndigit,
      &         '_neigh: Entering upper Hessenberg matrix H ')
       end if
-c 
+c
 c     %-----------------------------------------------------------%
 c     | 1. Compute the eigenvalues, the last components of the    |
 c     |    corresponding Schur vectors and the full Schur form T  |
 c     |    of the current upper Hessenberg matrix H.              |
-c     | slaqrb returns the full Schur form of H in WORKL(1:N**2)  |
+c     | slahqr returns the full Schur form of H in WORKL(1:N**2)  |
 c     | and the last components of the Schur vectors in BOUNDS.   |
 c     %-----------------------------------------------------------%
 c
       call slacpy ('All', n, n, h, ldh, workl, n)
-      call slaqrb (.true., n, 1, n, workl, n, ritzr, ritzi, bounds,
-     &             ierr)
+      do 5 j = 1, n-1
+          bounds(j) = zero
+   5  continue
+      bounds(n) = one
+      call slahqr(.true., .true., n, 1, n, workl, n, ritzr, ritzi, 1, 1,
+     &            bounds, 1, ierr)
       if (ierr .ne. 0) go to 9000
 c
       if (msglvl .gt. 1) then
@@ -240,7 +244,7 @@ c
 c           %----------------------%
 c           | Real eigenvalue case |
 c           %----------------------%
-c    
+c
             temp = snrm2( n, q(1,i), 1 )
             call sscal ( n, one / temp, q(1,i), 1 )
          else
@@ -254,7 +258,7 @@ c           | square root of two.                       |
 c           %-------------------------------------------%
 c
             if (iconj .eq. 0) then
-               temp = slapy2( snrm2( n, q(1,i), 1 ), 
+               temp = slapy2( snrm2( n, q(1,i), 1 ),
      &                        snrm2( n, q(1,i+1), 1 ) )
                call sscal ( n, one / temp, q(1,i), 1 )
                call sscal ( n, one / temp, q(1,i+1), 1 )
@@ -262,7 +266,7 @@ c
             else
                iconj = 0
             end if
-         end if         
+         end if
    10 continue
 c
       call sgemv ('T', n, n, one, q, ldq, bounds, 1, zero, workl, 1)
@@ -283,7 +287,7 @@ c
 c           %----------------------%
 c           | Real eigenvalue case |
 c           %----------------------%
-c    
+c
             bounds(i) = rnorm * abs( workl(i) )
          else
 c
