@@ -12,8 +12,8 @@ c  apply NP shifts implicitly resulting in
 c
 c     A*(V_{k}*Q) - (V_{k}*Q)*(Q^T* H_{k}*Q) = r_{k+p}*e_{k+p}^T * Q
 c
-c  where Q is an orthogonal matrix of order KEV+NP. Q is the product of 
-c  rotations resulting from the NP bulge chasing sweeps.  The updated Arnoldi 
+c  where Q is an orthogonal matrix of order KEV+NP. Q is the product of
+c  rotations resulting from the NP bulge chasing sweeps.  The updated Arnoldi
 c  factorization becomes:
 c
 c     A*VNEW_{k} - VNEW_{k}*HNEW_{k} = rnew_{k}*e_{k}^T.
@@ -51,7 +51,7 @@ c  H       Real (KEV+NP) by 2 array.  (INPUT/OUTPUT)
 c          INPUT: H contains the symmetric tridiagonal matrix of the
 c          Arnoldi factorization with the subdiagonal in the 1st column
 c          starting at H(2,1) and the main diagonal in the 2nd column.
-c          OUTPUT: H contains the updated tridiagonal matrix in the 
+c          OUTPUT: H contains the updated tridiagonal matrix in the
 c          KEV leading submatrix.
 c
 c  LDH     Integer.  (INPUT)
@@ -87,12 +87,12 @@ c\References:
 c  1. D.C. Sorensen, "Implicit Application of Polynomial Filters in
 c     a k-Step Arnoldi Method", SIAM J. Matr. Anal. Apps., 13 (1992),
 c     pp 357-385.
-c  2. R.B. Lehoucq, "Analysis and Implementation of an Implicitly 
+c  2. R.B. Lehoucq, "Analysis and Implementation of an Implicitly
 c     Restarted Arnoldi Iteration", Rice University Technical Report
 c     TR95-13, Department of Computational and Applied Mathematics.
 c
 c\Routines called:
-c     pivout  Parallel ARPACK utility routine that prints integers. 
+c     pivout  Parallel ARPACK utility routine that prints integers.
 c     arscnd  ARPACK utility routine for timing.
 c     psvout  Parallel ARPACK utility routine that prints vectors.
 c     pslamch ScaLAPACK routine that determines machine constants.
@@ -109,8 +109,8 @@ c     Danny Sorensen               Phuong Vu
 c     Richard Lehoucq              CRPC / Rice University
 c     Dept. of Computational &     Houston, Texas
 c     Applied Mathematics
-c     Rice University           
-c     Houston, Texas            
+c     Rice University
+c     Houston, Texas
 c
 c\Parallel Modifications
 c     Kristi Maschhoff
@@ -123,8 +123,8 @@ c FILE: sapps.F   SID: 1.3   DATE OF SID: 3/19/97
 c
 c\Remarks
 c  1. In this version, each shift is applied to all the subblocks of
-c     the tridiagonal matrix H and not just to the submatrix that it 
-c     comes from. This routine assumes that the subdiagonal elements 
+c     the tridiagonal matrix H and not just to the submatrix that it
+c     comes from. This routine assumes that the subdiagonal elements
 c     of H that are stored in h(1:kev+np,1) are nonegative upon input
 c     and enforce this condition upon output. This version incorporates
 c     deflation. See code for documentation.
@@ -160,7 +160,7 @@ c     | Array Arguments |
 c     %-----------------%
 c
       Real
-     &           h(ldh,2), q(ldq,kev+np), resid(n), shift(np), 
+     &           h(ldh,2), q(ldq,kev+np), resid(n), shift(np),
      &           v(ldv,kev+np), workd(2*n)
 c
 c     %------------%
@@ -186,7 +186,7 @@ c     %----------------------%
 c     | External Subroutines |
 c     %----------------------%
 c
-      external   saxpy, scopy, sscal, slacpy, slartg, slaset, psvout, 
+      external   saxpy, scopy, sscal, slacpy, slartg, slaset, psvout,
      &           pivout, arscnd, sgemv
 c
 c     %--------------------%
@@ -204,7 +204,7 @@ c
       intrinsic  abs
 c
 c     %----------------%
-c     | Data statments |
+c     | Data statements |
 c     %----------------%
 c
       data       first / .true. /
@@ -226,9 +226,9 @@ c     %-------------------------------%
 c
       call arscnd (t0)
       msglvl = msapps
-c 
-      kplusp = kev + np 
-c 
+c
+      kplusp = kev + np
+c
 c     %----------------------------------------------%
 c     | Initialize Q to the identity matrix of order |
 c     | kplusp used to accumulate the rotations.     |
@@ -241,7 +241,7 @@ c     | Quick return if there are no shifts to apply |
 c     %----------------------------------------------%
 c
       if (np .eq. 0) go to 9000
-c 
+c
 c     %----------------------------------------------------------%
 c     | Apply the np shifts implicitly. Apply each shift to the  |
 c     | whole matrix and not just to the submatrix from which it |
@@ -249,7 +249,7 @@ c     | comes.                                                   |
 c     %----------------------------------------------------------%
 c
       do 90 jj = 1, np
-c 
+c
          istart = itop
 c
 c        %----------------------------------------------------------%
@@ -272,11 +272,11 @@ c
             big   = abs(h(i,2)) + abs(h(i+1,2))
             if (h(i+1,1) .le. epsmch*big) then
                if (msglvl .gt. 0) then
-                  call pivout (comm, logfil, 1, i, ndigit, 
+                  call pivout (comm, logfil, 1, i, ndigit,
      &                 '_sapps: deflation at row/column no.')
-                  call pivout (comm, logfil, 1, jj, ndigit, 
-     &                 '_sapps: occured before shift number.')
-                  call psvout (comm, logfil, 1, h(i+1,1), ndigit, 
+                  call pivout (comm, logfil, 1, jj, ndigit,
+     &                 '_sapps: occurred before shift number.')
+                  call psvout (comm, logfil, 1, h(i+1,1), ndigit,
      &                 '_sapps: the corresponding off diagonal element')
                end if
                h(i+1,1) = zero
@@ -288,7 +288,7 @@ c
    40    continue
 c
          if (istart .lt. iend) then
-c 
+c
 c           %--------------------------------------------------------%
 c           | Construct the plane rotation G'(istart,istart+1,theta) |
 c           | that attempts to drive h(istart+1,1) to zero.          |
@@ -297,7 +297,7 @@ c
              f = h(istart,2) - shift(jj)
              g = h(istart+1,1)
              call slartg (f, g, c, s, r)
-c 
+c
 c            %-------------------------------------------------------%
 c            | Apply rotation to the left and right of H;            |
 c            | H <- G' * H * G,  where G = G(istart,istart+1,theta). |
@@ -307,11 +307,11 @@ c
              a1 = c*h(istart,2)   + s*h(istart+1,1)
              a2 = c*h(istart+1,1) + s*h(istart+1,2)
              a4 = c*h(istart+1,2) - s*h(istart+1,1)
-             a3 = c*h(istart+1,1) - s*h(istart,2) 
+             a3 = c*h(istart+1,1) - s*h(istart,2)
              h(istart,2)   = c*a1 + s*a2
              h(istart+1,2) = c*a4 - s*a3
              h(istart+1,1) = c*a3 + s*a4
-c 
+c
 c            %----------------------------------------------------%
 c            | Accumulate the rotation in the matrix Q;  Q <- Q*G |
 c            %----------------------------------------------------%
@@ -334,7 +334,7 @@ c            | zero.                                        |
 c            %----------------------------------------------%
 c
              do 70 i = istart+1, iend-1
-c 
+c
 c               %----------------------------------------------%
 c               | Construct the plane rotation G'(i,i+1,theta) |
 c               | that zeros the i-th bulge that was created   |
@@ -362,28 +362,28 @@ c
                    c = -c
                    s = -s
                 end if
-c 
+c
 c               %--------------------------------------------%
 c               | Apply rotation to the left and right of H; |
 c               | H <- G * H * G',  where G = G(i,i+1,theta) |
 c               %--------------------------------------------%
 c
                 h(i,1) = r
-c 
+c
                 a1 = c*h(i,2)   + s*h(i+1,1)
                 a2 = c*h(i+1,1) + s*h(i+1,2)
                 a3 = c*h(i+1,1) - s*h(i,2)
                 a4 = c*h(i+1,2) - s*h(i+1,1)
-c 
+c
                 h(i,2)   = c*a1 + s*a2
                 h(i+1,2) = c*a4 - s*a3
                 h(i+1,1) = c*a3 + s*a4
-c 
+c
 c               %----------------------------------------------------%
 c               | Accumulate the rotation in the matrix Q;  Q <- Q*G |
 c               %----------------------------------------------------%
 c
-                do 50 j = 1, min( i+jj, kplusp ) 
+                do 50 j = 1, min( i+jj, kplusp )
                    a1       =   c*q(j,i) + s*q(j,i+1)
                    q(j,i+1) = - s*q(j,i) + c*q(j,i+1)
                    q(j,i)   = a1
@@ -436,16 +436,16 @@ c
 c     %------------------------------------------%
 c     | All shifts have been applied. Check for  |
 c     | more possible deflation that might occur |
-c     | after the last shift is applied.         |                               
+c     | after the last shift is applied.         |
 c     %------------------------------------------%
 c
       do 100 i = itop, kplusp-1
          big   = abs(h(i,2)) + abs(h(i+1,2))
          if (h(i+1,1) .le. epsmch*big) then
             if (msglvl .gt. 0) then
-               call pivout (comm, logfil, 1, i, ndigit, 
+               call pivout (comm, logfil, 1, i, ndigit,
      &              '_sapps: deflation at row/column no.')
-               call psvout (comm, logfil, 1, h(i+1,1), ndigit, 
+               call psvout (comm, logfil, 1, h(i+1,1), ndigit,
      &              '_sapps: the corresponding off diagonal element')
             end if
             h(i+1,1) = zero
@@ -458,13 +458,13 @@ c     | temporarily store the result in WORKD(N+1:2*N). |
 c     | This is not necessary if h(kev+1,1) = 0.         |
 c     %-------------------------------------------------%
 c
-      if ( h(kev+1,1) .gt. zero ) 
+      if ( h(kev+1,1) .gt. zero )
      &   call sgemv ('N', n, kplusp, one, v, ldv,
      &                q(1,kev+1), 1, zero, workd(n+1), 1)
-c 
+c
 c     %-------------------------------------------------------%
 c     | Compute column 1 to kev of (V*Q) in backward order    |
-c     | taking advantage that Q is an upper triangular matrix |    
+c     | taking advantage that Q is an upper triangular matrix |
 c     | with lower bandwidth np.                              |
 c     | Place results in v(:,kplusp-kev:kplusp) temporarily.  |
 c     %-------------------------------------------------------%
@@ -480,15 +480,15 @@ c     |  Move v(:,kplusp-kev+1:kplusp) into v(:,1:kev). |
 c     %-------------------------------------------------%
 c
       call slacpy ('All', n, kev, v(1,np+1), ldv, v, ldv)
-c 
+c
 c     %--------------------------------------------%
 c     | Copy the (kev+1)-st column of (V*Q) in the |
 c     | appropriate place if h(kev+1,1) .ne. zero. |
 c     %--------------------------------------------%
 c
-      if ( h(kev+1,1) .gt. zero ) 
+      if ( h(kev+1,1) .gt. zero )
      &     call scopy (n, workd(n+1), 1, v(1,kev+1), 1)
-c 
+c
 c     %-------------------------------------%
 c     | Update the residual vector:         |
 c     |    r <- sigmak*r + betak*v(:,kev+1) |
@@ -498,26 +498,26 @@ c     |    betak = e_{kev+1}'*H*e_{kev}     |
 c     %-------------------------------------%
 c
       call sscal (n, q(kplusp,kev), resid, 1)
-      if (h(kev+1,1) .gt. zero) 
+      if (h(kev+1,1) .gt. zero)
      &   call saxpy (n, h(kev+1,1), v(1,kev+1), 1, resid, 1)
 c
       if (msglvl .gt. 1) then
-         call psvout (comm, logfil, 1, q(kplusp,kev), ndigit, 
+         call psvout (comm, logfil, 1, q(kplusp,kev), ndigit,
      &      '_sapps: sigmak of the updated residual vector')
-         call psvout (comm, logfil, 1, h(kev+1,1), ndigit, 
+         call psvout (comm, logfil, 1, h(kev+1,1), ndigit,
      &      '_sapps: betak of the updated residual vector')
-         call psvout (comm, logfil, kev, h(1,2), ndigit, 
+         call psvout (comm, logfil, kev, h(1,2), ndigit,
      &      '_sapps: updated main diagonal of H for next iteration')
          if (kev .gt. 1) then
-         call psvout (comm, logfil, kev-1, h(2,1), ndigit, 
+         call psvout (comm, logfil, kev-1, h(2,1), ndigit,
      &      '_sapps: updated sub diagonal of H for next iteration')
          end if
       end if
 c
       call arscnd (t1)
       tsapps = tsapps + (t1 - t0)
-c 
- 9000 continue 
+c
+ 9000 continue
       return
 c
 c     %----------------%
