@@ -5,35 +5,35 @@ c\Name: pssaup2
 c
 c Message Passing Layer: BLACS
 c
-c\Description: 
+c\Description:
 c  Intermediate level interface called by pssaupd.
 c
 c\Usage:
-c  call pssaup2 
+c  call pssaup2
 c     ( COMM, IDO, BMAT, N, WHICH, NEV, NP, TOL, RESID, MODE, IUPD,
-c       ISHIFT, MXITER, V, LDV, H, LDH, RITZ, BOUNDS, Q, LDQ, WORKL, 
+c       ISHIFT, MXITER, V, LDV, H, LDH, RITZ, BOUNDS, Q, LDQ, WORKL,
 c       IPNTR, WORKD, INFO )
 c
 c\Arguments
 c
 c  COMM, IDO, BMAT, N, WHICH, NEV, TOL, RESID: same as defined in pssaupd.
 c  MODE, ISHIFT, MXITER: see the definition of IPARAM in pssaupd.
-c  
+c
 c  NP      Integer.  (INPUT/OUTPUT)
-c          Contains the number of implicit shifts to apply during 
-c          each Arnoldi/Lanczos iteration.  
-c          If ISHIFT=1, NP is adjusted dynamically at each iteration 
+c          Contains the number of implicit shifts to apply during
+c          each Arnoldi/Lanczos iteration.
+c          If ISHIFT=1, NP is adjusted dynamically at each iteration
 c          to accelerate convergence and prevent stagnation.
-c          This is also roughly equal to the number of matrix-vector 
+c          This is also roughly equal to the number of matrix-vector
 c          products (involving the operator OP) per Arnoldi iteration.
 c          The logic for adjusting is contained within the current
 c          subroutine.
 c          If ISHIFT=0, NP is the number of shifts the user needs
-c          to provide via reverse comunication. 0 < NP < NCV-NEV.
+c          to provide via reverse communication. 0 < NP < NCV-NEV.
 c          NP may be less than NCV-NEV since a leading block of the current
 c          upper Tridiagonal matrix has split off and contains "unwanted"
 c          Ritz values.
-c          Upon termination of the IRA iteration, NP contains the number 
+c          Upon termination of the IRA iteration, NP contains the number
 c          of "converged" wanted Ritz values.
 c
 c  IUPD    Integer.  (INPUT)
@@ -44,18 +44,18 @@ c  V       Real N by (NEV+NP) array.  (INPUT/OUTPUT)
 c          The Lanczos basis vectors.
 c
 c  LDV     Integer.  (INPUT)
-c          Leading dimension of V exactly as declared in the calling 
+c          Leading dimension of V exactly as declared in the calling
 c          program.
 c
 c  H       Real (NEV+NP) by 2 array.  (OUTPUT)
 c          H is used to store the generated symmetric tridiagonal matrix
-c          The subdiagonal is stored in the first column of H starting 
+c          The subdiagonal is stored in the first column of H starting
 c          at H(2,1).  The main diagonal is stored in the second column
-c          of H starting at H(1,2). If pssaup2 converges store the 
+c          of H starting at H(1,2). If pssaup2 converges store the
 c          B-norm of the final residual vector in H(1,1).
 c
 c  LDH     Integer.  (INPUT)
-c          Leading dimension of H exactly as declared in the calling 
+c          Leading dimension of H exactly as declared in the calling
 c          program.
 c
 c  RITZ    Real array of length NEV+NP.  (OUTPUT)
@@ -65,33 +65,33 @@ c  BOUNDS  Real array of length NEV+NP.  (OUTPUT)
 c          BOUNDS(1:NEV) contain the error bounds corresponding to RITZ.
 c
 c  Q       Real (NEV+NP) by (NEV+NP) array.  (WORKSPACE)
-c          Private (replicated) work array used to accumulate the 
+c          Private (replicated) work array used to accumulate the
 c          rotation in the shift application step.
 c
 c  LDQ     Integer.  (INPUT)
 c          Leading dimension of Q exactly as declared in the calling
 c          program.
-c          
+c
 c  WORKL   Real array of length at least 3*(NEV+NP).  (INPUT/WORKSPACE)
 c          Private (replicated) array on each PE or array allocated on
-c          the front end.  It is used in the computation of the 
+c          the front end.  It is used in the computation of the
 c          tridiagonal eigenvalue problem, the calculation and
 c          application of the shifts and convergence checking.
 c          If ISHIFT .EQ. O and IDO .EQ. 3, the first NP locations
-c          of WORKL are used in reverse communication to hold the user 
+c          of WORKL are used in reverse communication to hold the user
 c          supplied shifts.
 c
 c  IPNTR   Integer array of length 3.  (OUTPUT)
-c          Pointer to mark the starting locations in the WORKD for 
+c          Pointer to mark the starting locations in the WORKD for
 c          vectors used by the Lanczos iteration.
 c          -------------------------------------------------------------
 c          IPNTR(1): pointer to the current operand vector X.
 c          IPNTR(2): pointer to the current result vector Y.
-c          IPNTR(3): pointer to the vector B * X when used in one of  
+c          IPNTR(3): pointer to the vector B * X when used in one of
 c                    the spectral transformation modes.  X is the current
 c                    operand.
 c          -------------------------------------------------------------
-c          
+c
 c  WORKD   Real work array of length 3*N.  (REVERSE COMMUNICATION)
 c          Distributed array to be used in the basic Lanczos iteration
 c          for reverse communication.  The user should not use WORKD
@@ -104,9 +104,9 @@ c          If INFO .NE. 0, RESID contains the initial residual vector,
 c                          possibly from a previous run.
 c          Error flag on output.
 c          =     0: Normal return.
-c          =     1: All possible eigenvalues of OP has been found.  
+c          =     1: All possible eigenvalues of OP has been found.
 c                   NP returns the size of the invariant subspace
-c                   spanning the operator OP. 
+c                   spanning the operator OP.
 c          =     2: No shifts could be applied.
 c          =    -8: Error return from trid. eigenvalue calculation;
 c                   This should never happen.
@@ -124,7 +124,7 @@ c\References:
 c  1. D.C. Sorensen, "Implicit Application of Polynomial Filters in
 c     a k-Step Arnoldi Method", SIAM J. Matr. Anal. Apps., 13 (1992),
 c     pp 357-385.
-c  2. R.B. Lehoucq, "Analysis and Implementation of an Implicitly 
+c  2. R.B. Lehoucq, "Analysis and Implementation of an Implicitly
 c     Restarted Arnoldi Iteration", Rice University Technical Report
 c     TR95-13, Department of Computational and Applied Mathematics.
 c  3. B.N. Parlett, "The Symmetric Eigenvalue Problem". Prentice-Hall,
@@ -134,15 +134,15 @@ c     Computer Physics Communications, 53 (1989), pp 169-179.
 c  5. B. Nour-Omid, B.N. Parlett, T. Ericson, P.S. Jensen, "How to
 c     Implement the Spectral Transformation", Math. Comp., 48 (1987),
 c     pp 663-673.
-c  6. R.G. Grimes, J.G. Lewis and H.D. Simon, "A Shifted Block Lanczos 
-c     Algorithm for Solving Sparse Symmetric Generalized Eigenproblems", 
+c  6. R.G. Grimes, J.G. Lewis and H.D. Simon, "A Shifted Block Lanczos
+c     Algorithm for Solving Sparse Symmetric Generalized Eigenproblems",
 c     SIAM J. Matr. Anal. Apps.,  January (1993).
 c  7. L. Reichel, W.B. Gragg, "Algorithm 686: FORTRAN Subroutines
 c     for Updating the QR decomposition", ACM TOMS, December 1990,
 c     Volume 16 Number 4, pp 369-377.
 c
 c\Routines called:
-c     psgetv0  Parallel ARPACK initial vector generation routine. 
+c     psgetv0  Parallel ARPACK initial vector generation routine.
 c     pssaitr  Parallel ARPACK Lanczos factorization routine.
 c     pssapps  Parallel ARPACK application of implicit shifts routine.
 c     ssconv   ARPACK convergence of Ritz values routine.
@@ -153,7 +153,7 @@ c     sstrqb   ARPACK routine that computes all eigenvalues and the
 c              last component of the eigenvectors of a symmetric
 c              tridiagonal matrix using the implicit QL or QR method.
 c     pivout   Parallel ARPACK utility routine that prints integers.
-c     second   ARPACK utility routine for timing.
+c     arscnd   ARPACK utility routine for timing.
 c     psvout   Parallel ARPACK utility routine that prints vectors.
 c     pslamch  ScaLAPACK routine that determines machine constants.
 c     scopy    Level 1 BLAS that copies one vector to another.
@@ -167,25 +167,25 @@ c     Danny Sorensen               Phuong Vu
 c     Richard Lehoucq              CRPC / Rice University
 c     Dept. of Computational &     Houston, Texas
 c     Applied Mathematics
-c     Rice University           
-c     Houston, Texas            
+c     Rice University
+c     Houston, Texas
 c
 c\Parallel Modifications
 c     Kristi Maschhoff
 c
 c\Revision history:
 c     Starting Point: Serial Code FILE: saup2.F   SID: 2.4
-c 
-c\SCCS Information: 
-c FILE: saup2.F   SID: 1.5   DATE OF SID: 05/20/98   
+c
+c\SCCS Information:
+c FILE: saup2.F   SID: 1.5   DATE OF SID: 05/20/98
 c
 c\EndLib
 c
 c-----------------------------------------------------------------------
 c
       subroutine pssaup2
-     &   ( comm, ido, bmat, n, which, nev, np, tol, resid, mode, iupd, 
-     &     ishift, mxiter, v, ldv, h, ldh, ritz, bounds, 
+     &   ( comm, ido, bmat, n, which, nev, np, tol, resid, mode, iupd,
+     &     ishift, mxiter, v, ldv, h, ldh, ritz, bounds,
      &     q, ldq, workl, ipntr, workd, info )
 c
 c
@@ -194,7 +194,7 @@ c     | BLACS Variables and Routines |
 c     %------------------------------%
 c
       integer    comm
-      external   sgsum2d 
+      external   sgsum2d
 c
 c
 c     %----------------------------------------------------%
@@ -220,8 +220,8 @@ c     %-----------------%
 c
       integer    ipntr(3)
       Real
-     &           bounds(nev+np), h(ldh,2), q(ldq,nev+np), resid(n), 
-     &           ritz(nev+np), v(ldv,nev+np), workd(3*n), 
+     &           bounds(nev+np), h(ldh,2), q(ldq,nev+np), resid(n),
+     &           ritz(nev+np), v(ldv,nev+np), workd(3*n),
      &           workl(3*(nev+np))
 c
 c     %------------%
@@ -238,8 +238,8 @@ c     %---------------%
 c
       character  wprime*2
       logical    cnorm, getv0, initv, update, ushift
-      integer    ierr, iter, j, kplusp, msglvl, nconv, nevbef, nev0, 
-     &           np0, nptemp, nevd2, nevm2, kp(3) 
+      integer    ierr, iter, j, kplusp, msglvl, nconv, nevbef, nev0,
+     &           np0, nptemp, nevd2, nevm2, kp(3)
       Real
      &           rnorm, temp, eps23
       save       cnorm, getv0, initv, update, ushift,
@@ -251,9 +251,9 @@ c     %----------------------%
 c     | External Subroutines |
 c     %----------------------%
 c
-      external   scopy, psgetv0, pssaitr, sscal, ssconv, 
+      external   scopy, psgetv0, pssaitr, sscal, ssconv,
      &           psseigt, pssgets, pssapps,
-     &           ssortr, psvout, pivout, second
+     &           ssortr, psvout, pivout, arscnd
 c
 c     %--------------------%
 c     | External Functions |
@@ -274,13 +274,13 @@ c     | Executable Statements |
 c     %-----------------------%
 c
       if (ido .eq. 0) then
-c 
+c
 c        %-------------------------------%
 c        | Initialize timing statistics  |
 c        | & message level for debugging |
 c        %-------------------------------%
 c
-         call second (t0)
+         call arscnd (t0)
          msglvl = msaup2
 c
 c        %---------------------------------%
@@ -310,7 +310,7 @@ c
          kplusp = nev0 + np0
          nconv  = 0
          iter   = 0
-c 
+c
 c        %---------------------------------------------%
 c        | Set flags for computing the first NEV steps |
 c        | of the Lanczos factorization.               |
@@ -333,7 +333,7 @@ c
             initv = .false.
          end if
       end if
-c 
+c
 c     %---------------------------------------------%
 c     | Get a possibly random starting vector and   |
 c     | force it into the range of the operator OP. |
@@ -342,7 +342,7 @@ c
    10 continue
 c
       if (getv0) then
-         call psgetv0 ( comm, ido, bmat, 1, initv, n, 1, v, ldv, 
+         call psgetv0 ( comm, ido, bmat, 1, initv, n, 1, v, ldv,
      &                  resid, rnorm, ipntr, workd, workl, info)
 c
          if (ido .ne. 99) go to 9000
@@ -350,7 +350,7 @@ c
          if (rnorm .eq. zero) then
 c
 c           %-----------------------------------------%
-c           | The initial vector is zero. Error exit. | 
+c           | The initial vector is zero. Error exit. |
 c           %-----------------------------------------%
 c
             info = -9
@@ -359,7 +359,7 @@ c
          getv0 = .false.
          ido  = 0
       end if
-c 
+c
 c     %------------------------------------------------------------%
 c     | Back from reverse communication: continue with update step |
 c     %------------------------------------------------------------%
@@ -378,15 +378,15 @@ c     | at the end of the current iteration |
 c     %-------------------------------------%
 c
       if (cnorm)  go to 100
-c 
+c
 c     %----------------------------------------------------------%
 c     | Compute the first NEV steps of the Lanczos factorization |
 c     %----------------------------------------------------------%
 c
-      call pssaitr (comm, ido, bmat, n, 0, nev0, mode, 
+      call pssaitr (comm, ido, bmat, n, 0, nev0, mode,
      &              resid, rnorm, v, ldv, h, ldh, ipntr,
      &              workd, workl, info)
-c 
+c
 c     %---------------------------------------------------%
 c     | ido .ne. 99 implies use of reverse communication  |
 c     | to compute operations involving OP and possibly B |
@@ -407,7 +407,7 @@ c
          info = -9999
          go to 1200
       end if
-c 
+c
 c     %--------------------------------------------------------------%
 c     |                                                              |
 c     |           M A I N  LANCZOS  I T E R A T I O N  L O O P       |
@@ -415,22 +415,22 @@ c     |           Each iteration implicitly restarts the Lanczos     |
 c     |           factorization in place.                            |
 c     |                                                              |
 c     %--------------------------------------------------------------%
-c 
+c
  1000 continue
 c
          iter = iter + 1
 c
          if (msglvl .gt. 0) then
-            call pivout (comm, logfil, 1, iter, ndigit, 
+            call pivout (comm, logfil, 1, iter, ndigit,
      &           '_saup2: **** Start of major iteration number ****')
          end if
          if (msglvl .gt. 1) then
-            call pivout (comm, logfil, 1, nev, ndigit, 
+            call pivout (comm, logfil, 1, nev, ndigit,
      &     '_saup2: The length of the current Lanczos factorization')
-            call pivout (comm, logfil, 1, np, ndigit, 
+            call pivout (comm, logfil, 1, np, ndigit,
      &           '_saup2: Extend the Lanczos factorization by')
          end if
-c 
+c
 c        %------------------------------------------------------------%
 c        | Compute NP additional steps of the Lanczos factorization.  |
 c        %------------------------------------------------------------%
@@ -439,10 +439,10 @@ c
    20    continue
          update = .true.
 c
-         call pssaitr (comm, ido, bmat, n, nev, np, mode, 
+         call pssaitr (comm, ido, bmat, n, nev, np, mode,
      &                 resid, rnorm, v, ldv, h, ldh, ipntr,
      &                 workd, workl, info)
-c 
+c
 c        %---------------------------------------------------%
 c        | ido .ne. 99 implies use of reverse communication  |
 c        | to compute operations involving OP and possibly B |
@@ -454,7 +454,7 @@ c
 c
 c           %-----------------------------------------------------%
 c           | pssaitr was unable to build an Lanczos factorization|
-c           | of length NEV0+NP0. INFO is returned with the size  |  
+c           | of length NEV0+NP0. INFO is returned with the size  |
 c           | of the factorization built. Exit main loop.         |
 c           %-----------------------------------------------------%
 c
@@ -466,16 +466,16 @@ c
          update = .false.
 c
          if (msglvl .gt. 1) then
-            call psvout (comm, logfil, 1, rnorm, ndigit, 
+            call psvout (comm, logfil, 1, rnorm, ndigit,
      &           '_saup2: Current B-norm of residual for factorization')
          end if
-c 
+c
 c        %--------------------------------------------------------%
 c        | Compute the eigenvalues and corresponding error bounds |
 c        | of the current symmetric tridiagonal matrix.           |
 c        %--------------------------------------------------------%
 c
-         call psseigt ( comm, rnorm, kplusp, h, ldh, ritz, bounds, 
+         call psseigt ( comm, rnorm, kplusp, h, ldh, ritz, bounds,
      &                  workl, ierr)
 c
          if (ierr .ne. 0) then
@@ -503,7 +503,7 @@ c        %---------------------------------------------------%
 c
          nev = nev0
          np = np0
-         call pssgets ( comm, ishift, which, nev, np, ritz, 
+         call pssgets ( comm, ishift, which, nev, np, ritz,
      &                  bounds, workl)
 c
 c        %-------------------%
@@ -542,11 +542,11 @@ c
                nev = nev + 1
             end if
  30      continue
-c 
-         if ( (nconv .ge. nev0) .or. 
+c
+         if ( (nconv .ge. nev0) .or.
      &        (iter .gt. mxiter) .or.
      &        (np .eq. 0) ) then
-c     
+c
 c           %------------------------------------------------%
 c           | Prepare to exit. Put the converged Ritz values |
 c           | and corresponding bounds in RITZ(1:NCONV) and  |
@@ -653,7 +653,7 @@ c              | Ritz values according to WHICH so that the   |
 c              | "threshold" value appears at the front of    |
 c              | ritz.                                        |
 c              %----------------------------------------------%
- 
+
                call ssortr(which, .true., nconv, ritz, bounds)
 c
             end if
@@ -673,13 +673,13 @@ c
             end if
 c
 c           %------------------------------------%
-c           | Max iterations have been exceeded. | 
+c           | Max iterations have been exceeded. |
 c           %------------------------------------%
 c
             if (iter .gt. mxiter .and. nconv .lt. nev) info = 1
 c
 c           %---------------------%
-c           | No shifts to apply. | 
+c           | No shifts to apply. |
 c           %---------------------%
 c
             if (np .eq. 0 .and. nconv .lt. nev0) info = 2
@@ -703,14 +703,14 @@ c
                nev = 2
             end if
             np  = kplusp - nev
-c     
+c
 c           %---------------------------------------%
 c           | If the size of NEV was just increased |
 c           | resort the eigenvalues.               |
 c           %---------------------------------------%
-c     
-            if (nevbef .lt. nev) 
-     &         call pssgets ( comm, ishift, which, nev, np, 
+c
+            if (nevbef .lt. nev)
+     &         call pssgets ( comm, ishift, which, nev, np,
      &                        ritz, bounds, workl)
 c
          end if
@@ -721,7 +721,7 @@ c
             if (msglvl .gt. 1) then
                kp(1) = nev
                kp(2) = np
-               call pivout (comm, logfil, 2, kp, ndigit, 
+               call pivout (comm, logfil, 2, kp, ndigit,
      &              '_saup2: NEV and NP .')
                call psvout (comm, logfil, nev, ritz(np+1), ndigit,
      &              '_saup2: "wanted" Ritz values.')
@@ -729,7 +729,7 @@ c
      &              '_saup2: Ritz estimates of the "wanted" values ')
             end if
          end if
-c 
+c
          if (ishift .eq. 0) then
 c
 c           %-----------------------------------------------------%
@@ -752,8 +752,8 @@ c        | in WORKL(1:NP)                     |
 c        %------------------------------------%
 c
          ushift = .false.
-c 
-c 
+c
+c
 c        %---------------------------------------------------------%
 c        | Move the NP shifts to the first NP locations of RITZ to |
 c        | free up WORKL.  This is for the non-exact shift case;   |
@@ -781,7 +781,7 @@ c        | After pssapps is done, we have a Lanczos                |
 c        | factorization of length NEV.                            |
 c        %---------------------------------------------------------%
 c
-         call pssapps ( comm, n, nev, np, ritz, v, ldv, h, ldh, resid, 
+         call pssapps ( comm, n, nev, np, ritz, v, ldv, h, ldh, resid,
      &                  q, ldq, workd)
 c
 c        %---------------------------------------------%
@@ -791,35 +791,35 @@ c        | the first step of the next call to pssaitr. |
 c        %---------------------------------------------%
 c
          cnorm = .true.
-         call second (t2)
+         call arscnd (t2)
          if (bmat .eq. 'G') then
             nbx = nbx + 1
             call scopy (n, resid, 1, workd(n+1), 1)
             ipntr(1) = n + 1
             ipntr(2) = 1
             ido = 2
-c 
+c
 c           %----------------------------------%
 c           | Exit in order to compute B*RESID |
 c           %----------------------------------%
-c 
+c
             go to 9000
          else if (bmat .eq. 'I') then
             call scopy (n, resid, 1, workd, 1)
          end if
-c 
+c
   100    continue
-c 
+c
 c        %----------------------------------%
 c        | Back from reverse communication; |
 c        | WORKD(1:N) := B*RESID            |
 c        %----------------------------------%
 c
          if (bmat .eq. 'G') then
-            call second (t3)
+            call arscnd (t3)
             tmvbx = tmvbx + (t3 - t2)
          end if
-c 
+c
          if (bmat .eq. 'G') then
             rnorm = sdot (n, resid, 1, workd, 1)
             call sgsum2d( comm, 'All', ' ', 1, 1, rnorm, 1, -1, -1 )
@@ -831,14 +831,14 @@ c
   130    continue
 c
          if (msglvl .gt. 2) then
-            call psvout (comm, logfil, 1, rnorm, ndigit, 
+            call psvout (comm, logfil, 1, rnorm, ndigit,
      &      '_saup2: B-norm of residual for NEV factorization')
             call psvout (comm, logfil, nev, h(1,2), ndigit,
      &           '_saup2: main diagonal of compressed H matrix')
             call psvout (comm, logfil, nev-1, h(2,1), ndigit,
      &           '_saup2: subdiagonal of compressed H matrix')
          end if
-c 
+c
       go to 1000
 c
 c     %---------------------------------------------------------------%
@@ -846,12 +846,12 @@ c     |                                                               |
 c     |  E N D     O F     M A I N     I T E R A T I O N     L O O P  |
 c     |                                                               |
 c     %---------------------------------------------------------------%
-c 
+c
  1100 continue
 c
       mxiter = iter
       nev = nconv
-c 
+c
  1200 continue
       ido = 99
 c
@@ -859,9 +859,9 @@ c     %------------%
 c     | Error exit |
 c     %------------%
 c
-      call second (t1)
+      call arscnd (t1)
       tsaup2 = t1 - t0
-c 
+c
  9000 continue
       return
 c
