@@ -21,7 +21,7 @@ c     A*VNEW_{k} - VNEW_{k}*HNEW_{k} = rnew_{k}*e_{k}^T.
 c
 c\Usage:
 c  call pznapps
-c     ( COMM, N, KEV, NP, SHIFT, V, LDV, H, LDH, RESID, Q, LDQ, 
+c     ( COMM, N, KEV, NP, SHIFT, V, LDV, H, LDH, RESID, Q, LDQ,
 c       WORKL, WORKD )
 c
 c\Arguments
@@ -32,7 +32,7 @@ c          Problem size, i.e. size of matrix A.
 c
 c  KEV     Integer.  (INPUT/OUTPUT)
 c          KEV+NP is the size of the input matrix H.
-c          KEV is the size of the updated matrix HNEW. 
+c          KEV is the size of the updated matrix HNEW.
 c
 c  NP      Integer.  (INPUT)
 c          Number of implicit shifts to be applied.
@@ -50,7 +50,7 @@ c          Leading dimension of V exactly as declared in the calling
 c          program.
 c
 c  H       Complex*16 (KEV+NP) by (KEV+NP) array.  (INPUT/OUTPUT)
-c          On INPUT, H contains the current KEV+NP by KEV+NP upper 
+c          On INPUT, H contains the current KEV+NP by KEV+NP upper
 c          Hessenberg matrix of the Arnoldi factorization.
 c          On OUTPUT, H contains the updated KEV by KEV upper Hessenberg
 c          matrix in the KEV leading submatrix.
@@ -61,7 +61,7 @@ c          program.
 c
 c  RESID   Complex*16 array of length N.  (INPUT/OUTPUT)
 c          On INPUT, RESID contains the the residual vector r_{k+p}.
-c          On OUTPUT, RESID is the update residual vector rnew_{k} 
+c          On OUTPUT, RESID is the update residual vector rnew_{k}
 c          in the first KEV locations.
 c
 c  Q       Complex*16 KEV+NP by KEV+NP work array.  (WORKSPACE)
@@ -116,9 +116,9 @@ c\Author
 c     Danny Sorensen               Phuong Vu
 c     Richard Lehoucq              CRPC / Rice University
 c     Dept. of Computational &     Houston, Texas
-c     Applied Mathematics 
-c     Rice University           
-c     Houston, Texas 
+c     Applied Mathematics
+c     Rice University
+c     Houston, Texas
 c
 c\Parallel Modifications
 c     Kristi Maschhoff
@@ -142,13 +142,14 @@ c
 c-----------------------------------------------------------------------
 c
       subroutine pznapps
-     &   ( comm, n, kev, np, shift, v, ldv, h, ldh, resid, q, ldq, 
+     &   ( comm, n, kev, np, shift, v, ldv, h, ldh, resid, q, ldq,
      &     workl, workd )
 c
 c     %--------------------%
 c     | MPI Communicator |
 c     %--------------------%
 c
+      include   'pcontext.h'
       integer   comm
 c
 c     %----------------------------------------------------%
@@ -169,7 +170,7 @@ c     | Array Arguments |
 c     %-----------------%
 c
       Complex*16
-     &           h(ldh,kev+np), resid(n), shift(np), 
+     &           h(ldh,kev+np), resid(n), shift(np),
      &           v(ldv,kev+np), q(ldq,kev+np), workd(2*n), workl(kev+np)
 c
 c     %------------%
@@ -188,25 +189,24 @@ c     | Local Scalars & Arrays |
 c     %------------------------%
 c
       integer    i, iend, istart, j, jj, kplusp, msglvl
-      logical    first
       Complex*16
      &           cdum, f, g, h11, h21, r, s, sigma, t
-      Double precision             
+      Double precision
      &           c,  ovfl, smlnum, ulp, unfl, tst1
-      save       first, ovfl, smlnum, ulp, unfl 
+      save       ovfl, smlnum, ulp, unfl
 c
 c     %----------------------%
 c     | External Subroutines |
 c     %----------------------%
 c
-      external   zaxpy, zcopy, zgemv, zscal, zlacpy, zlartg, 
+      external   zaxpy, zcopy, zgemv, zscal, zlacpy, zlartg,
      &           pzvout, zlaset, dlabad, pzmout, arscnd, pivout
 c
 c     %--------------------%
 c     | External Functions |
 c     %--------------------%
 c
-      Double precision                 
+      Double precision
      &           zlanhs, pdlamch10, dlapy2
       external   zlanhs, pdlamch10, dlapy2
 c
@@ -220,21 +220,20 @@ c     %---------------------%
 c     | Statement Functions |
 c     %---------------------%
 c
-      Double precision     
+      Double precision
      &           cabs1
       cabs1( cdum ) = abs( dble( cdum ) ) + abs( dimag( cdum ) )
 c
 c     %----------------%
-c     | Data statments |
+c     | Data statements |
 c     %----------------%
 c
-      data       first / .true. /
 c
 c     %-----------------------%
 c     | Executable Statements |
 c     %-----------------------%
 c
-      if (first) then
+      if (apps_first) then
 c
 c        %-----------------------------------------------%
 c        | Set machine-dependent constants for the       |
@@ -248,7 +247,7 @@ c
          call dlabad( unfl, ovfl )
          ulp = pdlamch10( comm, 'precision' )
          smlnum = unfl*( n / ulp )
-         first = .false.
+         apps_first = .false.
       end if
 c
 c     %-------------------------------%
@@ -258,9 +257,9 @@ c     %-------------------------------%
 c
       call arscnd (t0)
       msglvl = mcapps
-c 
-      kplusp = kev + np 
-c 
+c
+      kplusp = kev + np
+c
 c     %--------------------------------------------%
 c     | Initialize Q to the identity to accumulate |
 c     | the rotations and reflections              |
@@ -284,9 +283,9 @@ c
          sigma = shift(jj)
 c
          if (msglvl .gt. 2 ) then
-            call pivout (comm, logfil, 1, jj, ndigit, 
+            call pivout (comm, logfil, 1, jj, ndigit,
      &               '_napps: shift number.')
-            call pzvout (comm, logfil, 1, sigma, ndigit, 
+            call pzvout (comm, logfil, 1, sigma, ndigit,
      &               '_napps: Value of the shift ')
          end if
 c
@@ -304,14 +303,14 @@ c
             tst1 = cabs1( h( i, i ) ) + cabs1( h( i+1, i+1 ) )
             if( tst1.eq.rzero )
      &         tst1 = zlanhs( '1', kplusp-jj+1, h, ldh, workl )
-            if ( abs(dble(h(i+1,i))) 
+            if ( abs(dble(h(i+1,i)))
      &           .le. max(ulp*tst1, smlnum) )  then
                if (msglvl .gt. 0) then
-                  call pivout (comm, logfil, 1, i, ndigit, 
+                  call pivout (comm, logfil, 1, i, ndigit,
      &                 '_napps: matrix splitting at row/column no.')
-                  call pivout (comm, logfil, 1, jj, ndigit, 
+                  call pivout (comm, logfil, 1, jj, ndigit,
      &                 '_napps: matrix splitting with shift number.')
-                  call pzvout (comm, logfil, 1, h(i+1,i), ndigit, 
+                  call pzvout (comm, logfil, 1, h(i+1,i), ndigit,
      &                 '_napps: off diagonal element.')
                end if
                iend = i
@@ -323,9 +322,9 @@ c
    40    continue
 c
          if (msglvl .gt. 2) then
-             call pivout (comm, logfil, 1, istart, ndigit, 
+             call pivout (comm, logfil, 1, istart, ndigit,
      &                   '_napps: Start of current block ')
-             call pivout (comm, logfil, 1, iend, ndigit, 
+             call pivout (comm, logfil, 1, iend, ndigit,
      &                   '_napps: End of current block ')
          end if
 c
@@ -341,7 +340,7 @@ c
          h21 = h(istart+1,istart)
          f = h11 - sigma
          g = h21
-c 
+c
          do 80 i = istart, iend-1
 c
 c           %------------------------------------------------------%
@@ -361,7 +360,7 @@ c
             do 50 j = i, kplusp
                t        =  c*h(i,j) + s*h(i+1,j)
                h(i+1,j) = -conjg(s)*h(i,j) + c*h(i+1,j)
-               h(i,j)   = t   
+               h(i,j)   = t
    50       continue
 c
 c           %---------------------------------------------%
@@ -371,7 +370,7 @@ c
             do 60 j = 1, min(i+2,iend)
                t        =  c*h(j,i) + conjg(s)*h(j,i+1)
                h(j,i+1) = -s*h(j,i) + c*h(j,i+1)
-               h(j,i)   = t   
+               h(j,i)   = t
    60       continue
 c
 c           %-----------------------------------------------------%
@@ -381,7 +380,7 @@ c
             do 70 j = 1, min(i+jj, kplusp)
                t        =   c*q(j,i) + conjg(s)*q(j,i+1)
                q(j,i+1) = - s*q(j,i) + c*q(j,i+1)
-               q(j,i)   = t   
+               q(j,i)   = t
    70       continue
 c
 c           %---------------------------%
@@ -397,7 +396,7 @@ c
 c        %-------------------------------%
 c        | Finished applying the shift.  |
 c        %-------------------------------%
-c 
+c
   100    continue
 c
 c        %---------------------------------------------------------%
@@ -444,7 +443,7 @@ c
          tst1 = cabs1( h( i, i ) ) + cabs1( h( i+1, i+1 ) )
          if( tst1 .eq. rzero )
      &       tst1 = zlanhs( '1', kev, h, ldh, workl )
-         if( dble( h( i+1,i ) ) .le. max( ulp*tst1, smlnum ) ) 
+         if( dble( h( i+1,i ) ) .le. max( ulp*tst1, smlnum ) )
      &       h(i+1,i) = zero
  130  continue
 c
@@ -457,9 +456,9 @@ c     | of H would be zero as in exact arithmetic.      |
 c     %-------------------------------------------------%
 c
       if ( dble( h(kev+1,kev) ) .gt. rzero )
-     &   call zgemv ('N', n, kplusp, one, v, ldv, q(1,kev+1), 1, zero, 
+     &   call zgemv ('N', n, kplusp, one, v, ldv, q(1,kev+1), 1, zero,
      &                workd(n+1), 1)
-c 
+c
 c     %----------------------------------------------------------%
 c     | Compute column 1 to kev of (V*Q) in backward order       |
 c     | taking advantage of the upper Hessenberg structure of Q. |
@@ -476,14 +475,14 @@ c     |  Move v(:,kplusp-kev+1:kplusp) into v(:,1:kev). |
 c     %-------------------------------------------------%
 c
       call zlacpy ('A', n, kev, v(1,kplusp-kev+1), ldv, v, ldv)
-c 
+c
 c     %--------------------------------------------------------------%
 c     | Copy the (kev+1)-st column of (V*Q) in the appropriate place |
 c     %--------------------------------------------------------------%
 c
       if ( dble( h(kev+1,kev) ) .gt. rzero )
      &   call zcopy (n, workd(n+1), 1, v(1,kev+1), 1)
-c 
+c
 c     %-------------------------------------%
 c     | Update the residual vector:         |
 c     |    r <- sigmak*r + betak*v(:,kev+1) |
@@ -501,7 +500,7 @@ c
      &        '_napps: sigmak = (e_{kev+p}^T*Q)*e_{kev}')
          call pzvout (comm, logfil, 1, h(kev+1,kev), ndigit,
      &        '_napps: betak = e_{kev+1}^T*H*e_{kev}')
-         call pivout (comm, logfil, 1, kev, ndigit, 
+         call pivout (comm, logfil, 1, kev, ndigit,
      &               '_napps: Order of the final Hessenberg matrix ')
          if (msglvl .gt. 2) then
             call pzmout (comm, logfil, kev, kev, h, ldh, ndigit,
@@ -513,7 +512,7 @@ c
  9000 continue
       call arscnd (t1)
       tcapps = tcapps + (t1 - t0)
-c 
+c
       return
 c
 c     %----------------%
