@@ -2,7 +2,7 @@ c\BeginDoc
 c
 c\Name: sneupd
 c
-c\Description: 
+c\Description:
 c
 c  This subroutine returns the converged approximations to eigenvalues
 c  of A*z = lambda*B*z and (optionally):
@@ -28,34 +28,34 @@ c  in the comments that follow.  The computed orthonormal basis for the
 c  invariant subspace corresponding to these Ritz values is referred to as a
 c  Schur basis.
 c
-c  See documentation in the header of the subroutine SNAUPD for 
+c  See documentation in the header of the subroutine SNAUPD for
 c  definition of OP as well as other terms and the relation of computed
 c  Ritz values and Ritz vectors of OP with respect to the given problem
-c  A*z = lambda*B*z.  For a brief description, see definitions of 
+c  A*z = lambda*B*z.  For a brief description, see definitions of
 c  IPARAM(7), MODE and WHICH in the documentation of SNAUPD.
 c
 c\Usage:
-c  call sneupd 
-c     ( RVEC, HOWMNY, SELECT, DR, DI, Z, LDZ, SIGMAR, SIGMAI, WORKEV, BMAT, 
-c       N, WHICH, NEV, TOL, RESID, NCV, V, LDV, IPARAM, IPNTR, WORKD, WORKL, 
+c  call sneupd
+c     ( RVEC, HOWMNY, SELECT, DR, DI, Z, LDZ, SIGMAR, SIGMAI, WORKEV, BMAT,
+c       N, WHICH, NEV, TOL, RESID, NCV, V, LDV, IPARAM, IPNTR, WORKD, WORKL,
 c       LWORKL, INFO )
 c
 c\Arguments:
-c  RVEC    LOGICAL  (INPUT) 
-c          Specifies whether a basis for the invariant subspace corresponding 
-c          to the converged Ritz value approximations for the eigenproblem 
+c  RVEC    LOGICAL  (INPUT)
+c          Specifies whether a basis for the invariant subspace corresponding
+c          to the converged Ritz value approximations for the eigenproblem
 c          A*z = lambda*B*z is computed.
 c
 c             RVEC = .FALSE.     Compute Ritz values only.
 c
 c             RVEC = .TRUE.      Compute the Ritz vectors or Schur vectors.
-c                                See Remarks below. 
-c 
-c  HOWMNY  Character*1  (INPUT) 
-c          Specifies the form of the basis for the invariant subspace 
+c                                See Remarks below.
+c
+c  HOWMNY  Character*1  (INPUT)
+c          Specifies the form of the basis for the invariant subspace
 c          corresponding to the converged Ritz values that is to be computed.
 c
-c          = 'A': Compute NEV Ritz vectors; 
+c          = 'A': Compute NEV Ritz vectors;
 c          = 'P': Compute NEV Schur vectors;
 c          = 'S': compute some of the Ritz vectors, specified
 c                 by the logical array SELECT.
@@ -63,43 +63,43 @@ c
 c  SELECT  Logical array of dimension NCV.  (INPUT)
 c          If HOWMNY = 'S', SELECT specifies the Ritz vectors to be
 c          computed. To select the Ritz vector corresponding to a
-c          Ritz value (DR(j), DI(j)), SELECT(j) must be set to .TRUE.. 
+c          Ritz value (DR(j), DI(j)), SELECT(j) must be set to .TRUE..
 c          If HOWMNY = 'A' or 'P', SELECT is used as internal workspace.
 c
 c  DR      Real  array of dimension NEV+1.  (OUTPUT)
-c          If IPARAM(7) = 1,2 or 3 and SIGMAI=0.0  then on exit: DR contains 
-c          the real part of the Ritz  approximations to the eigenvalues of 
-c          A*z = lambda*B*z. 
+c          If IPARAM(7) = 1,2 or 3 and SIGMAI=0.0  then on exit: DR contains
+c          the real part of the Ritz  approximations to the eigenvalues of
+c          A*z = lambda*B*z.
 c          If IPARAM(7) = 3, 4 and SIGMAI is not equal to zero, then on exit:
-c          DR contains the real part of the Ritz values of OP computed by 
+c          DR contains the real part of the Ritz values of OP computed by
 c          SNAUPD. A further computation must be performed by the user
 c          to transform the Ritz values computed for OP by SNAUPD to those
 c          of the original system A*z = lambda*B*z. See remark 3 below.
 c
 c  DI      Real  array of dimension NEV+1.  (OUTPUT)
-c          On exit, DI contains the imaginary part of the Ritz value 
+c          On exit, DI contains the imaginary part of the Ritz value
 c          approximations to the eigenvalues of A*z = lambda*B*z associated
 c          with DR.
 c
-c          NOTE: When Ritz values are complex, they will come in complex 
-c                conjugate pairs.  If eigenvectors are requested, the 
-c                corresponding Ritz vectors will also come in conjugate 
-c                pairs and the real and imaginary parts of these are 
-c                represented in two consecutive columns of the array Z 
+c          NOTE: When Ritz values are complex, they will come in complex
+c                conjugate pairs.  If eigenvectors are requested, the
+c                corresponding Ritz vectors will also come in conjugate
+c                pairs and the real and imaginary parts of these are
+c                represented in two consecutive columns of the array Z
 c                (see below).
 c
 c  Z       Real  N by NEV+1 array if RVEC = .TRUE. and HOWMNY = 'A'. (OUTPUT)
-c          On exit, if RVEC = .TRUE. and HOWMNY = 'A', then the columns of 
-c          Z represent approximate eigenvectors (Ritz vectors) corresponding 
-c          to the NCONV=IPARAM(5) Ritz values for eigensystem 
-c          A*z = lambda*B*z. 
-c 
-c          The complex Ritz vector associated with the Ritz value 
-c          with positive imaginary part is stored in two consecutive 
-c          columns.  The first column holds the real part of the Ritz 
-c          vector and the second column holds the imaginary part.  The 
-c          Ritz vector associated with the Ritz value with negative 
-c          imaginary part is simply the complex conjugate of the Ritz vector 
+c          On exit, if RVEC = .TRUE. and HOWMNY = 'A', then the columns of
+c          Z represent approximate eigenvectors (Ritz vectors) corresponding
+c          to the NCONV=IPARAM(5) Ritz values for eigensystem
+c          A*z = lambda*B*z.
+c
+c          The complex Ritz vector associated with the Ritz value
+c          with positive imaginary part is stored in two consecutive
+c          columns.  The first column holds the real part of the Ritz
+c          vector and the second column holds the imaginary part.  The
+c          Ritz vector associated with the Ritz value with negative
+c          imaginary part is simply the complex conjugate of the Ritz vector
 c          associated with the positive imaginary part.
 c
 c          If  RVEC = .FALSE. or HOWMNY = 'P', then Z is not referenced.
@@ -114,11 +114,11 @@ c          The leading dimension of the array Z.  If Ritz vectors are
 c          desired, then  LDZ >= max( 1, N ).  In any case,  LDZ >= 1.
 c
 c  SIGMAR  Real   (INPUT)
-c          If IPARAM(7) = 3 or 4, represents the real part of the shift. 
+c          If IPARAM(7) = 3 or 4, represents the real part of the shift.
 c          Not referenced if IPARAM(7) = 1 or 2.
 c
 c  SIGMAI  Real   (INPUT)
-c          If IPARAM(7) = 3 or 4, represents the imaginary part of the shift. 
+c          If IPARAM(7) = 3 or 4, represents the imaginary part of the shift.
 c          Not referenced if IPARAM(7) = 1 or 2. See remark 3 below.
 c
 c  WORKEV  Real  work array of dimension 3*NCV.  (WORKSPACE)
@@ -183,10 +183,10 @@ c          =  0: Normal exit.
 c
 c          =  1: The Schur form computed by LAPACK routine slahqr
 c                could not be reordered by LAPACK routine strsen.
-c                Re-enter subroutine sneupd with IPARAM(5)=NCV and 
-c                increase the size of the arrays DR and DI to have 
-c                dimension at least dimension NCV and allocate at least NCV 
-c                columns for Z. NOTE: Not necessary if Z and V share 
+c                Re-enter subroutine sneupd with IPARAM(5)=NCV and
+c                increase the size of the arrays DR and DI to have
+c                dimension at least dimension NCV and allocate at least NCV
+c                columns for Z. NOTE: Not necessary if Z and V share
 c                the same space. Please notify the authors if this error
 c                occurs.
 c
@@ -218,7 +218,7 @@ c\References:
 c  1. D.C. Sorensen, "Implicit Application of Polynomial Filters in
 c     a k-Step Arnoldi Method", SIAM J. Matr. Anal. Apps., 13 (1992),
 c     pp 357-385.
-c  2. R.B. Lehoucq, "Analysis and Implementation of an Implicitly 
+c  2. R.B. Lehoucq, "Analysis and Implementation of an Implicitly
 c     Restarted Arnoldi Iteration", Rice University Technical Report
 c     TR95-13, Department of Computational and Applied Mathematics.
 c  3. B.N. Parlett & Y. Saad, "Complex Shift and Invert Strategies for
@@ -229,7 +229,7 @@ c\Routines called:
 c     ivout   ARPACK utility routine that prints integers.
 c     smout   ARPACK utility routine that prints matrices
 c     svout   ARPACK utility routine that prints vectors.
-c     sgeqr2  LAPACK routine that computes the QR factorization of 
+c     sgeqr2  LAPACK routine that computes the QR factorization of
 c             a matrix.
 c     slacpy  LAPACK matrix copy routine.
 c     slahqr  LAPACK routine to compute the real Schur form of an
@@ -237,7 +237,7 @@ c             upper Hessenberg matrix.
 c     slamch  LAPACK routine that determines machine constants.
 c     slapy2  LAPACK routine to compute sqrt(x**2+y**2) carefully.
 c     slaset  LAPACK matrix initialization routine.
-c     sorm2r  LAPACK routine that applies an orthogonal matrix in 
+c     sorm2r  LAPACK routine that applies an orthogonal matrix in
 c             factored form.
 c     strevc  LAPACK routine to compute the eigenvectors of a matrix
 c             in upper quasi-triangular form.
@@ -259,10 +259,10 @@ c  2. Schur vectors are an orthogonal representation for the basis of
 c     Ritz vectors. Thus, their numerical properties are often superior.
 c     If RVEC = .TRUE. then the relationship
 c             A * V(:,1:IPARAM(5)) = V(:,1:IPARAM(5)) * T, and
-c     trans(V(:,1:IPARAM(5))) * V(:,1:IPARAM(5)) = I are approximately 
-c     satisfied. Here T is the leading submatrix of order IPARAM(5) of the 
+c     trans(V(:,1:IPARAM(5))) * V(:,1:IPARAM(5)) = I are approximately
+c     satisfied. Here T is the leading submatrix of order IPARAM(5) of the
 c     real upper quasi-triangular matrix stored workl(ipntr(12)). That is,
-c     T is block upper triangular with 1-by-1 and 2-by-2 diagonal blocks; 
+c     T is block upper triangular with 1-by-1 and 2-by-2 diagonal blocks;
 c     each 2-by-2 diagonal block has its diagonal elements equal and its
 c     off-diagonal elements of opposite sign.  Corresponding to each 2-by-2
 c     diagonal block is a complex conjugate pair of Ritz values. The real
@@ -270,14 +270,14 @@ c     Ritz values are stored on the diagonal of T.
 c
 c  3. If IPARAM(7) = 3 or 4 and SIGMAI is not equal zero, then the user must
 c     form the IPARAM(5) Rayleigh quotients in order to transform the Ritz
-c     values computed by SNAUPD for OP to those of A*z = lambda*B*z. 
+c     values computed by SNAUPD for OP to those of A*z = lambda*B*z.
 c     Set RVEC = .true. and HOWMNY = 'A', and
-c     compute 
+c     compute
 c           trans(Z(:,I)) * A * Z(:,I) if DI(I) = 0.
-c     If DI(I) is not equal to zero and DI(I+1) = - D(I), 
+c     If DI(I) is not equal to zero and DI(I+1) = - D(I),
 c     then the desired real and imaginary parts of the Ritz value are
 c           trans(Z(:,I)) * A * Z(:,I) +  trans(Z(:,I+1)) * A * Z(:,I+1),
-c           trans(Z(:,I)) * A * Z(:,I+1) -  trans(Z(:,I+1)) * A * Z(:,I), 
+c           trans(Z(:,I)) * A * Z(:,I+1) -  trans(Z(:,I+1)) * A * Z(:,I),
 c     respectively.
 c     Another possibility is to set RVEC = .true. and HOWMNY = 'P' and
 c     compute trans(V(:,1:IPARAM(5))) * A * V(:,1:IPARAM(5)) and then an upper
@@ -286,20 +286,20 @@ c     2 above.
 c
 c\Authors
 c     Danny Sorensen               Phuong Vu
-c     Richard Lehoucq              CRPC / Rice University 
+c     Richard Lehoucq              CRPC / Rice University
 c     Chao Yang                    Houston, Texas
 c     Dept. of Computational &
-c     Applied Mathematics          
-c     Rice University           
-c     Houston, Texas            
-c 
-c\SCCS Information: @(#) 
-c FILE: neupd.F   SID: 2.7   DATE OF SID: 09/20/00   RELEASE: 2 
+c     Applied Mathematics
+c     Rice University
+c     Houston, Texas
+c
+c\SCCS Information: @(#)
+c FILE: neupd.F   SID: 2.7   DATE OF SID: 09/20/00   RELEASE: 2
 c
 c\EndLib
 c
 c-----------------------------------------------------------------------
-      subroutine sneupd(rvec , howmny, select, dr    , di,    
+      subroutine sneupd(rvec , howmny, select, dr    , di,
      &                   z    , ldz   , sigmar, sigmai, workev,
      &                   bmat , n     , which , nev   , tol,
      &                   resid, ncv   , v     , ldv   , iparam,
@@ -319,7 +319,7 @@ c
       character  bmat, howmny, which*2
       logical    rvec
       integer    info, ldz, ldv, lworkl, n, ncv, nev
-      Real      
+      Real
      &           sigmar, sigmai, tol
 c
 c     %-----------------%
@@ -328,16 +328,16 @@ c     %-----------------%
 c
       integer    iparam(11), ipntr(14)
       logical    select(ncv)
-      Real 
-     &           dr(nev+1)    , di(nev+1), resid(n)  , 
-     &           v(ldv,ncv)   , z(ldz,*) , workd(3*n), 
+      Real
+     &           dr(nev+1)    , di(nev+1), resid(n)  ,
+     &           v(ldv,ncv)   , z(ldz,*) , workd(3*n),
      &           workl(lworkl), workev(3*ncv)
 c
 c     %------------%
 c     | Parameters |
 c     %------------%
 c
-      Real 
+      Real
      &           one, zero
       parameter (one = 1.0E+0 , zero = 0.0E+0 )
 c
@@ -346,8 +346,8 @@ c     | Local Scalars |
 c     %---------------%
 c
       character  type*6
-      integer    bounds, ierr  , ih    , ihbds   , 
-     &           iheigr, iheigi, iconj , nconv   , 
+      integer    bounds, ierr  , ih    , ihbds   ,
+     &           iheigr, iheigi, iconj , nconv   ,
      &           invsub, iuptri, iwev  , iwork(1),
      &           j     , k     , ldh   , ldq     ,
      &           mode  , msglvl, outncv, ritzr   ,
@@ -355,7 +355,7 @@ c
      &           iri   , ibd   , ishift, numcnv  ,
      &           np    , jj    , nconv2
       logical    reord
-      Real 
+      Real
      &           conds  , rnorm, sep  , temp,
      &           vl(1,1), temp1, eps23
 c
@@ -363,16 +363,16 @@ c     %----------------------%
 c     | External Subroutines |
 c     %----------------------%
 c
-      external   scopy , sger  , sgeqr2, slacpy, 
-     &           slahqr, slaset, smout , sorm2r, 
-     &           strevc, strmm , strsen, sscal , 
+      external   scopy , sger  , sgeqr2, slacpy,
+     &           slahqr, slaset, smout , sorm2r,
+     &           strevc, strmm , strsen, sscal ,
      &           svout , ivout
 c
 c     %--------------------%
 c     | External Functions |
 c     %--------------------%
 c
-      Real 
+      Real
      &           slapy2, snrm2, slamch, sdot
       external   slapy2, snrm2, slamch, sdot
 c
@@ -385,7 +385,7 @@ c
 c     %-----------------------%
 c     | Executable Statements |
 c     %-----------------------%
-c 
+c
 c     %------------------------%
 c     | Set default parameters |
 c     %------------------------%
@@ -434,7 +434,7 @@ c
       else if (howmny .eq. 'S' ) then
          ierr = -12
       end if
-c     
+c
       if (mode .eq. 1 .or. mode .eq. 2) then
          type = 'REGULR'
       else if (mode .eq. 3 .and. sigmai .eq. zero) then
@@ -443,7 +443,7 @@ c
          type = 'REALPT'
       else if (mode .eq. 4 ) then
          type = 'IMAGPT'
-      else 
+      else
                                               ierr = -10
       end if
       if (mode .eq. 1 .and. bmat .eq. 'G')    ierr = -11
@@ -456,7 +456,7 @@ c
          info = ierr
          go to 9000
       end if
-c 
+c
 c     %--------------------------------------------------------%
 c     | Pointer into WORKL for address of H, RITZ, BOUNDS, Q   |
 c     | etc... and the remaining workspace.                    |
@@ -483,7 +483,7 @@ c     |       associated matrix representation of the invariant   |
 c     |       subspace for H.                                     |
 c     | GRAND total of NCV * ( 3 * NCV + 6 ) locations.           |
 c     %-----------------------------------------------------------%
-c     
+c
       ih     = ipntr(5)
       ritzr  = ipntr(6)
       ritzi  = ipntr(7)
@@ -537,7 +537,7 @@ c
       end if
 c
       if (rvec) then
-c     
+c
          reord = .false.
 c
 c        %---------------------------------------------------%
@@ -562,7 +562,7 @@ c        %-------------------------------------%
 c
          np     = ncv - nev
          ishift = 0
-         call sngets(ishift       , which     , nev       , 
+         call sngets(ishift       , which     , nev       ,
      &                np           , workl(irr), workl(iri),
      &                workl(bounds), workl     , workl(np+1))
 c
@@ -618,24 +618,24 @@ c        | of the upper Hessenberg matrix returned by SNAUPD.        |
 c        | Make a copy of the upper Hessenberg matrix.               |
 c        | Initialize the Schur vector matrix Q to the identity.     |
 c        %-----------------------------------------------------------%
-c     
+c
          call scopy(ldh*ncv, workl(ih), 1, workl(iuptri), 1)
-         call slaset('All', ncv, ncv, 
+         call slaset('All', ncv, ncv,
      &                zero , one, workl(invsub),
      &                ldq)
-         call slahqr(.true., .true.       , ncv, 
-     &                1     , ncv          , workl(iuptri), 
+         call slahqr(.true., .true.       , ncv,
+     &                1     , ncv          , workl(iuptri),
      &                ldh   , workl(iheigr), workl(iheigi),
-     &                1     , ncv          , workl(invsub), 
+     &                1     , ncv          , workl(invsub),
      &                ldq   , ierr)
-         call scopy(ncv         , workl(invsub+ncv-1), ldq, 
+         call scopy(ncv         , workl(invsub+ncv-1), ldq,
      &               workl(ihbds), 1)
-c     
+c
          if (ierr .ne. 0) then
             info = -8
             go to 9000
          end if
-c     
+c
          if (msglvl .gt. 1) then
             call svout(logfil, ncv, workl(iheigr), ndigit,
      &           '_neupd: Real part of the eigenvalues of H')
@@ -644,25 +644,25 @@ c
             call svout(logfil, ncv, workl(ihbds), ndigit,
      &           '_neupd: Last row of the Schur vector matrix')
             if (msglvl .gt. 3) then
-               call smout(logfil       , ncv, ncv   , 
+               call smout(logfil       , ncv, ncv   ,
      &                     workl(iuptri), ldh, ndigit,
      &              '_neupd: The upper quasi-triangular matrix ')
             end if
-         end if 
+         end if
 c
          if (reord) then
-c     
+c
 c           %-----------------------------------------------------%
-c           | Reorder the computed upper quasi-triangular matrix. | 
+c           | Reorder the computed upper quasi-triangular matrix. |
 c           %-----------------------------------------------------%
-c     
-            call strsen('None'       , 'V'          , 
+c
+            call strsen('None'       , 'V'          ,
      &                   select       , ncv          ,
-     &                   workl(iuptri), ldh          , 
-     &                   workl(invsub), ldq          , 
-     &                   workl(iheigr), workl(iheigi), 
+     &                   workl(iuptri), ldh          ,
+     &                   workl(invsub), ldq          ,
+     &                   workl(iheigr), workl(iheigi),
      &                   nconv2       , conds        ,
-     &                   sep          , workl(ihbds) , 
+     &                   sep          , workl(ihbds) ,
      &                   ncv          , iwork        ,
      &                   1            , ierr)
 c
@@ -681,12 +681,12 @@ c
                 call svout(logfil, ncv, workl(iheigi), ndigit,
      &           '_neupd: Imag part of the eigenvalues of H--reordered')
                 if (msglvl .gt. 3) then
-                   call smout(logfil       , ncv, ncv   , 
+                   call smout(logfil       , ncv, ncv   ,
      &                         workl(iuptri), ldq, ndigit,
      &             '_neupd: Quasi-triangular matrix after re-ordering')
                 end if
             end if
-c     
+c
          end if
 c
 c        %---------------------------------------%
@@ -703,23 +703,23 @@ c        | Place the computed eigenvalues of H into DR and DI |
 c        | if a spectral transformation was not used.         |
 c        %----------------------------------------------------%
 c
-         if (type .eq. 'REGULR') then 
+         if (type .eq. 'REGULR') then
             call scopy(nconv, workl(iheigr), 1, dr, 1)
             call scopy(nconv, workl(iheigi), 1, di, 1)
          end if
-c     
+c
 c        %----------------------------------------------------------%
 c        | Compute the QR factorization of the matrix representing  |
 c        | the wanted invariant subspace located in the first NCONV |
 c        | columns of workl(invsub,ldq).                            |
 c        %----------------------------------------------------------%
-c     
-         call sgeqr2(ncv, nconv , workl(invsub), 
+c
+         call sgeqr2(ncv, nconv , workl(invsub),
      &               ldq, workev, workev(ncv+1),
      &               ierr)
 c
 c        %---------------------------------------------------------%
-c        | * Postmultiply V by Q using sorm2r.                     |   
+c        | * Postmultiply V by Q using sorm2r.                     |
 c        | * Copy the first NCONV columns of VQ into Z.            |
 c        | * Postmultiply Z by R.                                  |
 c        | The N by NCONV matrix Z is now a matrix representation  |
@@ -729,15 +729,15 @@ c        | The first NCONV columns of V are now approximate Schur  |
 c        | vectors associated with the real upper quasi-triangular |
 c        | matrix of order NCONV in workl(iuptri)                  |
 c        %---------------------------------------------------------%
-c     
-         call sorm2r('Right', 'Notranspose', n            , 
+c
+         call sorm2r('Right', 'Notranspose', n            ,
      &                ncv   , nconv        , workl(invsub),
-     &                ldq   , workev       , v            , 
+     &                ldq   , workev       , v            ,
      &                ldv   , workd(n+1)   , ierr)
          call slacpy('All', n, nconv, v, ldv, z, ldz)
 c
          do 20 j=1, nconv
-c     
+c
 c           %---------------------------------------------------%
 c           | Perform both a column and row scaling if the      |
 c           | diagonal element of workl(invsub,ldq) is negative |
@@ -746,21 +746,21 @@ c           | quasi-triangular form of workl(iuptri,ldq)        |
 c           | Note that since Q is orthogonal, R is a diagonal  |
 c           | matrix consisting of plus or minus ones           |
 c           %---------------------------------------------------%
-c     
+c
             if (workl(invsub+(j-1)*ldq+j-1) .lt. zero) then
                call sscal(nconv, -one, workl(iuptri+j-1), ldq)
                call sscal(nconv, -one, workl(iuptri+(j-1)*ldq), 1)
             end if
-c     
+c
  20      continue
-c     
+c
          if (howmny .eq. 'A') then
-c     
+c
 c           %--------------------------------------------%
-c           | Compute the NCONV wanted eigenvectors of T | 
+c           | Compute the NCONV wanted eigenvectors of T |
 c           | located in workl(iuptri,ldq).              |
 c           %--------------------------------------------%
-c     
+c
             do 30 j=1, ncv
                if (j .le. nconv) then
                   select(j) = .true.
@@ -769,8 +769,8 @@ c
                end if
  30         continue
 c
-            call strevc('Right', 'Select'     , select       , 
-     &                   ncv    , workl(iuptri), ldq          , 
+            call strevc('Right', 'Select'     , select       ,
+     &                   ncv    , workl(iuptri), ldq          ,
      &                   vl     , 1            , workl(invsub),
      &                   ldq    , ncv          , outncv       ,
      &                   workev , ierr)
@@ -779,7 +779,7 @@ c
                 info = -9
                 go to 9000
             end if
-c     
+c
 c           %------------------------------------------------%
 c           | Scale the returning eigenvectors so that their |
 c           | Euclidean norms are all one. LAPACK subroutine |
@@ -787,22 +787,22 @@ c           | strevc returns each eigenvector normalized so  |
 c           | that the element of largest magnitude has      |
 c           | magnitude 1;                                   |
 c           %------------------------------------------------%
-c     
+c
             iconj = 0
             do 40 j=1, nconv
 c
                if ( workl(iheigi+j-1) .eq. zero ) then
-c     
+c
 c                 %----------------------%
 c                 | real eigenvalue case |
 c                 %----------------------%
-c     
+c
                   temp = snrm2( ncv, workl(invsub+(j-1)*ldq), 1 )
-                  call sscal( ncv, one / temp, 
+                  call sscal( ncv, one / temp,
      &                 workl(invsub+(j-1)*ldq), 1 )
 c
                else
-c     
+c
 c                 %-------------------------------------------%
 c                 | Complex conjugate pair case. Note that    |
 c                 | since the real and imaginary part of      |
@@ -812,15 +812,15 @@ c                 | square root of two.                       |
 c                 %-------------------------------------------%
 c
                   if (iconj .eq. 0) then
-                     temp = slapy2(snrm2(ncv, 
-     &                                   workl(invsub+(j-1)*ldq), 
+                     temp = slapy2(snrm2(ncv,
+     &                                   workl(invsub+(j-1)*ldq),
      &                                   1),
-     &                             snrm2(ncv, 
+     &                             snrm2(ncv,
      &                                   workl(invsub+j*ldq),
-     &                                   1))  
-                     call sscal(ncv, one/temp, 
+     &                                   1))
+                     call sscal(ncv, one/temp,
      &                           workl(invsub+(j-1)*ldq), 1 )
-                     call sscal(ncv, one/temp, 
+                     call sscal(ncv, one/temp,
      &                           workl(invsub+j*ldq), 1 )
                      iconj = 1
                   else
@@ -860,7 +860,7 @@ c
                call svout(logfil, ncv, workl(ihbds), ndigit,
      &              '_neupd: Last row of the eigenvector matrix for T')
                if (msglvl .gt. 3) then
-                  call smout(logfil, ncv, ncv, workl(invsub), ldq, 
+                  call smout(logfil, ncv, ncv, workl(invsub), ldq,
      &                 ndigit, '_neupd: The eigenvector matrix for T')
                end if
             end if
@@ -876,32 +876,32 @@ c           | Compute the QR factorization of the eigenvector matrix  |
 c           | associated with leading portion of T in the first NCONV |
 c           | columns of workl(invsub,ldq).                           |
 c           %---------------------------------------------------------%
-c     
-            call sgeqr2(ncv, nconv , workl(invsub), 
+c
+            call sgeqr2(ncv, nconv , workl(invsub),
      &                   ldq, workev, workev(ncv+1),
      &                   ierr)
-c     
+c
 c           %----------------------------------------------%
-c           | * Postmultiply Z by Q.                       |   
+c           | * Postmultiply Z by Q.                       |
 c           | * Postmultiply Z by R.                       |
-c           | The N by NCONV matrix Z is now contains the  | 
+c           | The N by NCONV matrix Z is now contains the  |
 c           | Ritz vectors associated with the Ritz values |
 c           | in workl(iheigr) and workl(iheigi).          |
 c           %----------------------------------------------%
-c     
+c
             call sorm2r('Right', 'Notranspose', n            ,
      &                   ncv  , nconv        , workl(invsub),
      &                   ldq  , workev       , z            ,
      &                   ldz  , workd(n+1)   , ierr)
-c     
+c
             call strmm('Right'   , 'Upper'       , 'No transpose',
      &                  'Non-unit', n            , nconv         ,
      &                  one       , workl(invsub), ldq           ,
      &                  z         , ldz)
-c     
+c
          end if
-c     
-      else 
+c
+      else
 c
 c        %------------------------------------------------------%
 c        | An approximate invariant subspace is not needed.     |
@@ -914,7 +914,7 @@ c
          call scopy(nconv, workl(ritzi), 1, workl(iheigi), 1)
          call scopy(nconv, workl(bounds), 1, workl(ihbds), 1)
       end if
-c 
+c
 c     %------------------------------------------------%
 c     | Transform the Ritz values and possibly vectors |
 c     | and corresponding error bounds of OP to those  |
@@ -923,26 +923,26 @@ c     %------------------------------------------------%
 c
       if (type .eq. 'REGULR') then
 c
-         if (rvec) 
-     &      call sscal(ncv, rnorm, workl(ihbds), 1)     
-c     
-      else 
-c     
+         if (rvec)
+     &      call sscal(ncv, rnorm, workl(ihbds), 1)
+c
+      else
+c
 c        %---------------------------------------%
 c        |   A spectral transformation was used. |
 c        | * Determine the Ritz estimates of the |
 c        |   Ritz values in the original system. |
 c        %---------------------------------------%
-c     
+c
          if (type .eq. 'SHIFTI') then
 c
-            if (rvec) 
+            if (rvec)
      &         call sscal(ncv, rnorm, workl(ihbds), 1)
 c
             do 50 k=1, ncv
-               temp = slapy2( workl(iheigr+k-1), 
+               temp = slapy2( workl(iheigr+k-1),
      &                        workl(iheigi+k-1) )
-               workl(ihbds+k-1) = abs( workl(ihbds+k-1) ) 
+               workl(ihbds+k-1) = abs( workl(ihbds+k-1) )
      &                          / temp / temp
  50         continue
 c
@@ -957,26 +957,26 @@ c
  70         continue
 c
          end if
-c     
+c
 c        %-----------------------------------------------------------%
 c        | *  Transform the Ritz values back to the original system. |
 c        |    For TYPE = 'SHIFTI' the transformation is              |
 c        |             lambda = 1/theta + sigma                      |
 c        |    For TYPE = 'REALPT' or 'IMAGPT' the user must from     |
-c        |    Rayleigh quotients or a projection. See remark 3 above.| 
+c        |    Rayleigh quotients or a projection. See remark 3 above.|
 c        | NOTES:                                                    |
 c        | *The Ritz vectors are not affected by the transformation. |
 c        %-----------------------------------------------------------%
-c     
-         if (type .eq. 'SHIFTI') then 
+c
+         if (type .eq. 'SHIFTI') then
 c
             do 80 k=1, ncv
-               temp = slapy2( workl(iheigr+k-1), 
+               temp = slapy2( workl(iheigr+k-1),
      &                        workl(iheigi+k-1) )
-               workl(iheigr+k-1) = workl(iheigr+k-1)/temp/temp 
-     &                           + sigmar   
+               workl(iheigr+k-1) = workl(iheigr+k-1)/temp/temp
+     &                           + sigmar
                workl(iheigi+k-1) = -workl(iheigi+k-1)/temp/temp
-     &                           + sigmai   
+     &                           + sigmai
  80         continue
 c
             call scopy(nconv, workl(iheigr), 1, dr, 1)
@@ -1006,7 +1006,7 @@ c
          call svout(logfil, nconv, workl(ihbds), ndigit,
      &   '_neupd: Associated Ritz estimates.')
       end if
-c 
+c
 c     %-------------------------------------------------%
 c     | Eigenvector Purification step. Formally perform |
 c     | one of inverse subspace iteration. Only used    |
@@ -1028,19 +1028,22 @@ c        %------------------------------------------------%
 c
          iconj = 0
          do 110 j=1, nconv
-            if (workl(iheigi+j-1) .eq. zero) then
+            if ((workl(iheigi+j-1) .eq. zero) .and.
+     &           (workl(iheigr+j-1) .ne. zero)) then
                workev(j) =  workl(invsub+(j-1)*ldq+ncv-1) /
      &                      workl(iheigr+j-1)
             else if (iconj .eq. 0) then
                temp = slapy2( workl(iheigr+j-1), workl(iheigi+j-1) )
-               workev(j) = ( workl(invsub+(j-1)*ldq+ncv-1) * 
-     &                       workl(iheigr+j-1) +
-     &                       workl(invsub+j*ldq+ncv-1) * 
-     &                       workl(iheigi+j-1) ) / temp / temp
-               workev(j+1) = ( workl(invsub+j*ldq+ncv-1) * 
-     &                         workl(iheigr+j-1) -
-     &                         workl(invsub+(j-1)*ldq+ncv-1) * 
-     &                         workl(iheigi+j-1) ) / temp / temp
+               if (temp. ne. zero) then
+                  workev(j) = ( workl(invsub+(j-1)*ldq+ncv-1) *
+     &                          workl(iheigr+j-1) +
+     &                          workl(invsub+j*ldq+ncv-1) *
+     &                          workl(iheigi+j-1) ) / temp / temp
+                  workev(j+1) = ( workl(invsub+j*ldq+ncv-1) *
+     &                            workl(iheigr+j-1) -
+     &                            workl(invsub+(j-1)*ldq+ncv-1) *
+     &                            workl(iheigi+j-1) ) / temp / temp
+               end if
                iconj = 1
             else
                iconj = 0
@@ -1059,7 +1062,7 @@ c
  9000 continue
 c
       return
-c     
+c
 c     %---------------%
 c     | End of SNEUPD |
 c     %---------------%
